#
# spec file for package nagios
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif
%if ! %{defined _rundir}
  %define _rundir %{_localstatedir}/run
%endif

%if 0%{?suse_version} >= 1230
%bcond_without systemd
%else
%bcond_with systemd
%endif

Name:           nagios
Version:        4.5.4
Release:        1.5
Summary:        The Nagios Network Monitor
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            http://www.nagios.org/
Source0:        %{name}-%{version}.tar.gz
Source1:        rc%{name}
Source3:        %{name}.sysconfig
Source4:        suse.de-nagios
Source5:        nagios.8
Source6:        nagiosstats.8
Source8:        upgrade_nagios.sh
Source9:        upgrade_nagios.8
Source10:       %{name}-README.SuSE
Source11:       %{name}-html-pages.tar.bz2
Source12:       %{name}.service
Source13:       %{name}.tmpfiles
Source14:       %{name}-archive.timer
Source15:       %{name}-archive.service
Source20:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM return 1 in int main()
Patch4:         nagios-random_data.patch
# PATCH-FIX-OPENSUSE disable Nagios online update checks for distributed packages
Patch11:        nagios-disable_phone_home.patch
# PATCH-FIX-OPENSUSE fake compile time in json sources to avoid problems in OBS
Patch14:        nagios-4.0.6-remove-date-time.patch
# PATCH-FIX-OPENSUSE patch to not truncate performance data
Patch16:        nagios-output-length.patch
# PATCH-FIX-UPSTREAM allow ppc64le builds in contrib Makefile
Patch18:        nagios-4.4.3-enable-ppc64le.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  bzip2
BuildRequires:  freetype2-devel
BuildRequires:  gd-devel
BuildRequires:  gperf
BuildRequires:  iputils
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  mailx
BuildRequires:  nagios-rpm-macros
BuildRequires:  net-tools
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  procps
BuildRequires:  unzip
BuildRequires:  zlib-devel
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
%else
Recommends:     cron
%endif
Provides:       monitoring_daemon
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  /bin/logger
Requires(pre):  coreutils
Requires(pre):  grep
%if 0%{?suse_version} 
Requires(pre):  %fillup_prereq
Recommends:     %{name}-www
# this package contains shared tools with icinga
Recommends:     monitoring-tools
Recommends:     icinga-monitoring-tools
Recommends:     %{name}-plugins
Recommends:     traceroute
Requires(pre):  system-user-nagios
%else
Requires(pre):  shadow-utils
%endif
Requires(pre):  permissions
Requires(pre):  sed
Requires:       mailx
%define         nslockfile_dir /run/%{name}
%define         nslockfile %nslockfile_dir/%{name}.pid
%define         apache2_sysconfdir %{_sysconfdir}/apache2/conf.d
# Macro that print mesages to syslog at package (un)install time
%define         nnmmsg logger -t %{name}/rpm

%description
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Nagios is written in C and is designed
to run under Linux (and some other *NIX variants) as a background
process, intermittently running checks on various services that you
specify.

The actual service checks are performed by separate "plugin" programs
which return the status of the checks to Nagios. The plugins are
available at http://nagios-plugins.org/.

This package provides core programs for Nagios. The web interface,
documentation, and development files are built as separate packages.


%package www
Summary:        Provides the HTML and CGI files for the Nagios web interface
Group:          System/Monitoring
Requires:       %{name} = %{version}
Requires:       gd
Requires:       mod_php_any
Requires:       php
Provides:       monitoring_webfrontend
Requires(pre):  /bin/logger
Requires(pre):  coreutils
Requires(pre):  gawk
Requires(pre):  grep
Requires(pre):  sed
%if 0%{?suse_version}
Requires(pre):  apache2
Requires(pre):  shadow
%else
Requires(pre):  httpd
Requires(pre):  shadow-utils
%endif

%description www
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Nagios is written in C and is designed
to run under Linux (and some other *NIX variants) as a background
process, intermittently running checks on various services that you
specify.

Several CGI programs are included with Nagios in order to allow you to
view the current service status, problem history, notification history,
and log file via the web. This package provides the HTML and CGI files
for the Nagios web interface.


%package theme-exfoliation
Summary:        Nagios Core web interface
Group:          System/Monitoring
Requires(pre):  nagios-theme-switcher
Requires:       nagios-www >= 3.0
BuildArch:      noarch

%description theme-exfoliation
Exfoliation is a simple makeover for the Nagios Core web interface. It consists
of two folders that overlay on a stock Nagios installation.


%package www-dch
Summary:        HTML and CGI files that do not call home
Group:          System/Monitoring
Requires:       %{name}-www = %{version}
BuildArch:      noarch

%description www-dch
Several CGI programs are included with Nagios in order to allow you to
view the current service status, problem history, notification history,
and log file via the web.

Since Version 3.1, some of those CGI files and the Nagios process itself
try to detect the latest version and fetching news feeds from the upstream
server www.nagios.org.

This additional package provides simply HTML files that do not "call
home" and also allow to run the web interface without PHP support.

There is also an offline version of the documentation included in this
package.

Note: The HTML pages use 'side' and 'main' and frame targets.


%package contrib
Summary:        Files from the contrib directory
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description contrib
This package contains all the files from the contrib directory


%package devel
Summary:        Development files for Nagios
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       gcc

%description devel
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Nagios is written in C and is designed
to run under Linux (and some other *NIX variants) as a background
process, intermittently running checks on various services that you
specify.

This package provides include files that Nagios-related applications
may compile against.


%prep
%setup -q
%if 0%{?suse_version} < 01500
%patch -P 4 -p1
%patch -P 11 -p1
%patch -P 14 -p1
%patch -P 16 -p1
%patch -P 18 -p1
%else
%autopatch -p1
%endif
find -name ".gitignore" | xargs rm
# fixing permissions the dirty way....
chmod 644 Changelog LEGAL LICENSE README.md sample-config/README sample-config/template-object/README
# README.SuSE file
sed -e 's@DATADIR@%{_datadir}/%{name}@g' -e 's@SYSCONFDIR@%{nagios_sysconfdir}@g' %{SOURCE10} > README.SUSE
# we do not use /usr/local ...
pushd contrib/eventhandlers 1>/dev/null
for f in $(find . -type f) ; do
    F=$(mktemp temp.XXXXXX)
    sed "s=/usr/local/nagios/var/rw/=%{nagios_spooldir}/=; \
         s=NscaBin\=\"/usr/local/nagios/libexec/send_nsca\"=NscaBin\=\"%{_bindir}/send_nsca\"=; \
         s=NscaCfg\=\"/usr/local/nagios/etc/send_nsca.cfg\"=NscaCfg\=\"%{_sysconfdir}/nsca.cfg\"=; \
         s=/usr/local/nagios/libexec/eventhandlers/=%{nagios_eventhandlerdir}/=; \
         s=/var/nagios/rw/nagios.qh=%{nagios_localstatedir}/nagios.qh=; \
         s=/usr/local/nagios/libexec/=%{nagios_plugindir}/=" ${f} > ${F}
    mv ${F} ${f}
done
popd 1>/dev/null
sed -i "s|/usr/bin/env ruby|%{_bindir}/ruby|g" contrib/nagios-qh.rb
mv contrib/exfoliation/readme.txt README_Theme_Exfoliation.txt

%build
export PATH_TO_TRACEROUTE="%{_sbindir}/traceroute"; \
%configure \
	--prefix=%{_prefix} \
	--exec-prefix=%{_sbindir} \
	--bindir=%{_sbindir} \
	--sbindir=%{nagios_cgidir} \
	--libexecdir=%{nagios_plugindir} \
	--datadir=%{nagios_datadir} \
	--sysconfdir=%{nagios_sysconfdir} \
	--with-init-dir=%{_sysconfdir}/init.d \
	--localstatedir=%{nagios_localstatedir} \
	--with-cgibindir=%{nagios_cgidir} \
	--with-cgiurl=/%{name}/cgi-bin \
	--with-htmurl=/%{name} \
	--with-httpd-conf=%{apache2_sysconfdir} \
	--with-checkresult-dir=%{nagios_spooldir} \
	--with-lockfile=%{nslockfile} \
	--with-nagios-user=%{nagios_user} \
	--with-nagios-group=%{nagios_group} \
	--with-command-user=%{nagios_command_user} \
	--with-command-group=%{nagios_command_group} \
	--with-gd-lib=%{_libdir} \
	--with-gd-inc=%{_includedir} \
	--with-template-objects \
	--with-template-extinfo \
	--with-perlcache \
	--enable-event-broker

#
# make daemonchk.cgi and event handlers
#
make %{?_smp_mflags} all
#
# Build documentation
#
make dox
#
# Build contrib stuff
#
make %{?_smp_mflags} -C contrib

%install
mkdir -p %{buildroot}/%{nagios_logdir}/archives
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%apache2_sysconfdir/
mkdir -p %{buildroot}%nslockfile_dir
make install install-commandmode install-config install-webconf install-classicui\
    DESTDIR=%{buildroot} \
    INSTALL_OPTS="" \
    COMMAND_OPTS="" \
    INIT_OPTS=""
make install -C contrib \
    DESTDIR=%{buildroot} \
    INSTALL_OPTS=""
# install event handlers
install -d -m0755 %{buildroot}/%{nagios_eventhandlerdir}
cp -afpv contrib/eventhandlers/* %{buildroot}%{nagios_eventhandlerdir}/
find %{buildroot}%{nagios_eventhandlerdir}/ -type f -exec chmod +x {} +
# install directory for event brokers like ndoutils
install -d -m0755 %{buildroot}%{nagios_localstatedir}/brokers
# install headers for development package
mkdir -p %{buildroot}%{_includedir}/%{name}/lib
install -p -m644 include/*.h %{buildroot}%{_includedir}/%{name}/
install -m644 lib/*.h %{buildroot}/%{_includedir}/%{name}/lib
#
# cleanup sample-conf dir for including in docdir
#
find sample-config/ -name "*.in" -delete
find sample-config/ -name "*.in.orig" -delete
sed -e 's|command_file=.*|command_file=%{nagios_command_file}|g' \
    -e 's|/var/lib/nagios/nagios.log|%{nagios_logdir}/nagios.log|g' \
    -e 's|/var/lib/nagios/archives|%{nagios_logdir}/archives|g' \
    -e 's|/var/lib/nagios/rw/nagios.qh|%{nagios_localstatedir}/nagios.qh|g' \
    -e 's|^lock_file=.*|lock_file=%nslockfile|g' \
    %{buildroot}/%{nagios_sysconfdir}/nagios.cfg > %{buildroot}%{_sysconfdir}/%{name}/nagios.cfg.tmp
mv %{buildroot}/%{nagios_sysconfdir}/nagios.cfg.tmp %{buildroot}%{_sysconfdir}/%{name}/nagios.cfg
#
# Install documentation
#
cp -fr Documentation/html/* %{buildroot}%{nagios_datadir}/docs/
#
# Install libnagios
#
install -Dm644 lib/libnagios.a %{buildroot}%{_libdir}/libnagios.a
#
# install SuSE specials
#
# init-script
%if %{with systemd}
ln -s -f %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
install -D -m0644 %{SOURCE12} %{buildroot}/%{_unitdir}/%{name}.service
install -D -m0644 %{SOURCE13} %{buildroot}/%{_prefix}/lib/tmpfiles.d/%{name}.conf
%else
install -D -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/%{name}
ln -sf ../../etc/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
touch %{buildroot}%{nslockfile}
# sysconfig script
install -D -m 0644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.%{name}
%endif
# install cronjob (gzip' the logfiles)
%if %{with systemd}
sed -e 's|__NAGIOS_USER__|%{nagios_user}|g' \
    -e 's|__NAGIOS_GROUP__|%{nagios_group}|g' %{SOURCE4} > %{buildroot}%{_sbindir}/nagios-archive
install -Dm0644 %{SOURCE14} %{buildroot}/%{_unitdir}/nagios-archive.timer
install -Dm0644 %{SOURCE15} %{buildroot}/%{_unitdir}/nagios-archive.service
# created via tmpfilesd - create here for ghosting it
mkdir -p %{buildroot}%{_rundir}/%{name}
%else
mkdir %{buildroot}%{_sysconfdir}/cron.weekly
sed -e 's|__NAGIOS_USER__|%{nagios_user}|g' \
    -e 's|__NAGIOS_GROUP__|%{nagios_group}|g' %{SOURCE4} > %{buildroot}%{_sysconfdir}/cron.weekly/%{name}
%endif
# install empty htpasswd file (boo#961115)
touch %{buildroot}%{_sysconfdir}/%{name}/htpasswd.users
# important ghost files
touch %{buildroot}%{nagios_state_retention_file}
touch %{buildroot}%{nagios_status_file}
touch %{buildroot}%{nagios_logdir}/config.err
# install manpages
install -Dm644 %{SOURCE5} %{buildroot}%{_mandir}/man8/%{name}.8
install -Dm644 %{SOURCE6} %{buildroot}%{_mandir}/man8/nagiostats.8
# we use nagios_spooldir for this
test -d %{buildroot}%{nagios_localstatedir}/rw && rmdir %{buildroot}%{nagios_localstatedir}/rw
# install plain html files to allow users to use Nagios without internet connection
# and without PHP at all
pushd %{buildroot}%{nagios_datadir} >/dev/null
tar -xf %{SOURCE11}
sed -i "s|3.4.3|%{version}|g" main.html
popd >/dev/null
# install upgrade script
install -m755 %{SOURCE8} %{buildroot}%{_sbindir}/upgrade_nagios
install -m644 %{SOURCE9} %{buildroot}%{_mandir}/man8/upgrade_nagios.8
# delete monitoring-tools because they are provided by monitoring-tools package
rm -f %{buildroot}/%{_sbindir}/convertcfg
rm -f %{buildroot}/%{_sbindir}/mini_epn
rm -f %{buildroot}/%{_sbindir}/new_mini_epn
# create exfoliation theme in separate folder
mkdir -p %{buildroot}%{_datadir}/nagios-themes/exfoliation
cp -a %{buildroot}%{nagios_datadir}/* %{buildroot}%{_datadir}/nagios-themes/exfoliation/
rm -rf %{buildroot}%{_datadir}/nagios-themes/exfoliation/{stylesheets,images}
mv -fv contrib/exfoliation/{stylesheets,images} %{buildroot}%{_datadir}/nagios-themes/exfoliation/
rmdir contrib/exfoliation
%fdupes %{buildroot}%{_datadir}/nagios-themes/exfoliation/


%check
NAGIOS_CFGFILE=$(mktemp /tmp/nagios.cfg-XXXXXX)
sed -e 's|/var/|%{buildroot}/var/|g' \
	-e 's|/etc/|%{buildroot}/etc/|g' %{buildroot}%{nagios_sysconfdir}/nagios.cfg > "$NAGIOS_CFGFILE"
%{buildroot}%{_sbindir}/nagios -v "$NAGIOS_CFGFILE"
rm "$NAGIOS_CFGFILE"


%if %{with systemd}
%pre
  %service_add_pre %{name}.service %{name}-archive.service %{name}-archive.timer
%endif

%post
# Update ?
if [ ${1:-0} -gt 1 ]; then
  if [ -f %{nagios_sysconfdir}/nagios.cfg ]; then
    %{nnmmsg} "Please run %{_sbindir}/upgrade_nagios %{nagios_sysconfdir}/nagios.cfg to upgrade your installation."
  fi
else
  # First installation: create an alias for the default nagiosadmin user
  if [ -r etc/aliases ]; then
    if ! grep -q "^nagiosadmin:" etc/aliases; then
        echo -e "nagiosadmin:\troot" >> etc/aliases
	    %{nnmmsg} "Added alias for user nagiosadmin to /etc/aliases"
        if [ -x usr/bin/newaliases ]; then
            usr/bin/newaliases &>/dev/null || true
        fi
    fi
  fi
fi
%if %{with systemd}
  %service_add_post %{name}.service %{name}-archive.service %{name}-archive.timer
  systemd-tmpfiles --create %{_prefix}/lib/tmpfiles.d/%{name}.conf
%else
%{fillup_and_insserv %{name}}
%if 0%{?sles_version} != 11
  %set_permissions /etc/cron.weekly/
%endif
%endif
%if 0%{?sles_version} != 11
  %set_permissions /var/spool/nagios/
%endif

%preun
%if %{with systemd}
  %service_del_preun %{name}.service %{name}-archive.service %{name}-archive.timer
%else
  %stop_on_removal %{name}
%endif

%postun
%if %{with systemd}
  %service_del_postun %{name}.service %{name}-archive.service %{name}-archive.timer
%else
  %restart_on_update %{name}
  %{insserv_cleanup}
%endif

%verifyscript
%if ! %{with systemd}
  %verify_permissions -e /etc/cron.weekly/
%endif
%verify_permissions -e /var/spool/nagios/

%post www
wwwusr=%{nagios_command_user}
if [ -f etc/apache2/uid.conf ]; then
    # If apache is installed, and we can find the apache user, set a shell var
    wwwusr=$(awk '/^[ \t]*User[ \t]+[a-zA-Z0-9]+/ {print $2}' etc/apache2/uid.conf)
fi
# if apache user is not in nagios_command_group, add it
if id -Gn $wwwusr 2>/dev/null | grep -q %{nagios_command_group} >/dev/null 2>&1 ; then
    : # $wwwusr (default: %%nagios_command_user) is already in Nagios cmd group
else
    # modify apache user, adding it to nagios_command_group
    usermod -a -G %{nagios_command_group} $wwwusr
    %{nnmmsg} "User $wwwusr added to group %{nagios_command_group} so sending commands to Nagios from the CGI is possible."
fi
# Update ?
if [ ${1:-0} -eq 1 ]; then
  if [ -x %{_sbindir}/a2enmod ]; then
    # enable authentification in apache config
      %{_sbindir}/a2enmod authn_file >/dev/null 
      %{_sbindir}/a2enmod auth_basic >/dev/null
      %{_sbindir}/a2enmod authz_user >/dev/null 
      %{_sbindir}/a2enmod version >/dev/null 
      # enable php in apache config
      %{_sbindir}/a2enmod php >/dev/null || :
  fi
  %if %{with systemd}
  %{_bindir}/systemctl try-restart apache2
  %else
  %restart_on_update apache2
  %endif
fi

%post www-dch
# Update ?
if [ ${1:-0} -eq 1 ]; then
  %if %{with systemd}
    %{_bindir}/systemctl try-restart apache2
  %else
    %restart_on_update apache2
  %endif
fi

%post theme-exfoliation
if [ ${1:-0} -eq 1 ]; then
    # Only switch the theme if we're not in update mode.
    if [ -x %{_sbindir}/switch-nagios-theme ]; then
        %{_sbindir}/switch-nagios-theme -f exfoliation || :
    fi
fi

%postun theme-exfoliation
if [ ${1:-0} -eq 1 ]; then
    # Only switch the theme if we're not in update mode.
    if [ -x %{_sbindir}/switch-nagios-theme ]; then
        %{_sbindir}/switch-nagios-theme exfoliation || :
    fi
fi

%files
%defattr(0644,root,root,0755)
%doc Changelog LEGAL LICENSE README.md README.SUSE UPGRADING THANKS sample-config/
%dir %{nagios_libdir}
%dir %{nagios_plugindir}
%exclude %{nagios_cgidir}/*
%{_mandir}/man8/%{name}*
%{_sbindir}/rc%{name}
%attr(0755,root,root) %{_sbindir}/upgrade_nagios
%{_mandir}/man8/upgrade_nagios.8*
%if %{with systemd}
%{_unitdir}/%{name}.service
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%attr(0755,root,root) %{_sbindir}/nagios-archive
%{_unitdir}/nagios-archive.timer
%{_unitdir}/nagios-archive.service
%else
%{_fillupdir}/sysconfig.%{name}
%attr(0755,root,root) %{_sysconfdir}/init.d/%{name}
%ghost %dir %{nslockfile_dir}
%attr(0644,%{nagios_user},%{nagios_group}) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{nslockfile}
%if 0%{?sles_version} != 11
%dir %{_sysconfdir}/cron.weekly
%endif
%attr(0755,root,root) %{_sysconfdir}/cron.weekly/*
%endif
%config(noreplace) %{nagios_sysconfdir}/*.cfg
%config(noreplace) %{nagios_sysconfdir}/objects/*.cfg
%ghost %config(missingok,noreplace) %attr(0644,%{nagios_user},%{nagios_group}) %{nagios_logdir}/config.err
%ghost %dir %{_rundir}/%{name}
# directories with special handling:
%attr(0755,root,%{nagios_command_group})           %dir %{nagios_sysconfdir}
%attr(0755,root,%{nagios_command_group})           %dir %{nagios_sysconfdir}/objects
%attr(2775,%{nagios_user},%{nagios_command_group}) %dir %{nagios_spooldir}
%attr(0775,%{nagios_user},%{nagios_command_group}) %dir %{nagios_localstatedir}
%attr(0755,%{nagios_user},%{nagios_group})         %dir %{nagios_logdir}
%attr(0755,%{nagios_user},%{nagios_group})         %dir %{nagios_logdir}/archives
# files with special handling
%config(noreplace) %attr(0640,root,%{nagios_group}) %{nagios_sysconfdir}/resource.cfg
%attr(0600,%{nagios_user},%{nagios_group}) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{nagios_state_retention_file}
%attr(0664,%{nagios_user},%{nagios_group}) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{nagios_status_file}
%attr(0750,root,%{nagios_command_group}) %{_sbindir}/%{name}
%attr(0750,root,%{nagios_command_group}) %{_sbindir}/nagiostats

%files www
%defattr(0644,root,root,0755)
%dir %{nagios_cgidir}
%dir %{nagios_datadir}
%attr(0755,root,root) %{nagios_cgidir}/*
%{nagios_datadir}/*
%config(noreplace) %{apache2_sysconfdir}/%{name}.conf
%attr(0640,root,%nagios_command_group) %config(missingok,noreplace) %{_sysconfdir}/%{name}/htpasswd.users
%exclude %{nagios_datadir}/index.html
%exclude %{nagios_datadir}/main.html
%exclude %{nagios_datadir}/side.html

%files theme-exfoliation
%defattr(0644,root,root,0755)
%doc README_Theme_Exfoliation.txt
%dir %{_datadir}/nagios-themes
%{_datadir}/nagios-themes/exfoliation/

%files www-dch
%defattr(0644,root,root,0755)
%{nagios_datadir}/index.html
%{nagios_datadir}/main.html
%{nagios_datadir}/side.html

%files contrib 
%defattr(-,root,root)
%doc contrib/README contrib/nagios-qh.rb
%dir %{nagios_eventhandlerdir}
%attr(0755,root,root) %{nagios_eventhandlerdir}/*

%files devel
%defattr(644,root,root,0755)
%{_includedir}/%{name}/
%{_libdir}/libnagios.a

%changelog
* Thu Aug 15 2024 Lars Vogdt <lars@linux-schulserver.de>
- update to 4.5.4
  * Fix inconsistent links for 'View {Trends,Alert Histogram} For
  This {Host,Service}' (Mauricio Faria de Oliveira)
  * Fix broken links from removing AngularJS pages in 4.5.3 (Dylan Anderson)
* Wed Jun 19 2024 Lars Vogdt <lars@linux-schulserver.de>
- update to 4.5.3
  * Update jQuery (#960) (Dylan Anderson)
  * Remove pages using outdated AngularJS framework (#960) (Dylan Anderson)
  * Fix html encoding of some ascii characters (#813) (Dylan Anderson)
  * Updated several page links to use 'nofollow' (#965) - (Griffin Westerman)
* Mon May 13 2024 Lars Vogdt <lars@linux-schulserver.de>
- update to 4.5.2
  * Fix handling of timeperiods w/ downtime availability calculations
    in the Availability CGI report (Sebastian Wolf)
  * Fix build when compiling against musl libc (#952) (Sebastian Wolf)
  * Fix downtime comment using current time instead of the downtime's
    entry time (#910) (Dylan Anderson)
* Tue Apr 16 2024 Lars Vogdt <lars@linux-schulserver.de>
- update to 4.5.1
  * Fix text rendering in Configuration -> Command Expansion when the
    command ends in whitespace
    (Thanks Joran LEREEC for reporting this issue)
- from 4.5.0
  Note: this release is backward-compatible, but does include updates
  to the header files.
  If you are using any NEB modules in your monitoring solution, you will
  need to recompile them with the new nagios-4.5.0 headers to avoid
  segmentation faults.
  ENHANCEMENTS
  * Add event_handler_period configuration option to hosts and services (#913)
  * Add external commands CHANGE_HOST_EVENT_HANDLER_TIMEPERIOD
    and CHANGE_SVC_EVENT_HANDLER_TIMEPERIOD (#913)
  * Added support for separating your build directory from your
    source directory (#867)
- from older versions:
  * Fix missing macros when running performance data commands (#904)
  * Fix broken logo images in status pages (regression from 4.4.12) (#917)
  * Clean up most compiler warnings on GCC and clang (#901)
  * Fix incorrect HTML entity escaping in CGIs (#907, #902)
  * Fix issue where predictive dependency checks were not being scheduled for services (#908)
  * Fix several typos (#898, #884)
  * Fix incorrect error message in preflight check (#865)
  * Fix use-after-free in qh_deregister_handler (#866)
  * Fix memory leak in qh_deregister_handler (#866)
  * Fix mismatched host/service behavior when changing from SOFT to HARD state (#891)
  * Minor performance improvements in CGI utility functions (#866)
  * Fix memory leak in nagiostats.c when using -c, -s, -d, or -D multiple times (#888)
  * Improve service scheduling at startup (#887)
  * Fixed check_attempts remaining high during a HARD service recovery (#837)
  * Fixed memory leak in NERD (#872)
  * Fixed crash when checking for updates using SSL
- removed patches:
  * nagios-4.1.0-add_KOHANNA.conf - not supported any longer
  * nagios-fix_encoding_trends.cgi.patch - fixed upstream
- refreshed patches:
  * nagios-disable_phone_home.patch - disable page tour in cgi.cfg
  * nagios-random_data.patch - rebase
  * nagios-4.0.6-remove-date-time.patch - rebase
  * nagios-4.4.3-enable-ppc64le.patch - rebase
  * nagios-output-length.patch - rebase
- removed scripts and configs:
  * nagios-exec-start-post - obsolete (fixes bsc#1202929)
  * nagios-exec-start-pre  - obsolete (fixes bsc#1202929)
  * nagios_systemd         - integrated in nagios.service
  * nagios-4.1.0-add_KOHANNA.conf - unsupported
- updated nagios.service
  * use correct commandline options
  * add ExecStopPost to remove the command file
  * get rid of EnvironmentFile
- reduce amount of rpmlintrc exceptions
- use service file for downloading the sources
- require procps (ps) for building
- recommend traceroute (for WAP -> statuswml.cgi & traceroute.cgi)
- Nagios plugins can be found under http://nagios-plugins.org/ now.
- use /run/nagios instead of /var/run/nagios as tmp-dir
- create and own /run/nagios as ghost directory
- substitute the distribution path names more general in nagios.cfg
- use symlink to /sbin/service for rcnagios instead of adjusted startup file
- package readme file for exfoliation theme
- package nagios-qh.rb (Query Handler interface example) in nagios-contrib
- run check macro and test the shipped nagios.cfg
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Feb  9 2024 Lars Vogdt <lars@linux-schulserver.de>
- remove some old rpmlintrc entries
- remove old (< 12.0) SUSE macros from spec file
- nagios-dch and nagios-contrib can be noarch
- use autopatch macro
- set right permission and ownership for /var/log/nagios/config.err
  even if this file is just a ghost file in RPM
- use /run/nagios instead of /var/run/nagios for pid file
- get rid of really old (SLE9) fix for nagios command group (was
  group www at that time). Since SLE10, we use and own group
  (nagcmd) instead. As we do not support to migrate from SLE9 to
  SLE11 and beyond directly, this migration should have been done
  long time ago already
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Do not provide user/group symbols and actually stop generating
  those users/groups alltogether. The package system-user-nagios is
  taking care of the user setup.
* Tue Feb  6 2024 Marcus Meissner <meissner@suse.com>
- provide user(nagios), group(nagios), group(wwwrun), user(nagcmd)
  bsc#1219600
* Thu Sep 15 2022 Lars Vogdt <lars@linux-schulserver.de>
- do not change ownership of resource_file (/etc/nagios/resource.cfg)
  during (re-)start: nagios does not have enough permissions to do
  it anyway.
  Fixes bsc#1192316 - thanks to Kai Lappalainen
* Fri May 13 2022 Andre Klaerner <kandre@ak-online.be>
- 4.4.7 - 2022-04-14
  FIXES
  * Fixed checkboxes in jsonquery.html (#778) (Rfferrao87)
  * Added SSL support for version update check (Sebastian Wolf)
  * Note: NEB modules using the priority/scheduling queues in libnagios may need to update headers due to symbol conflicts with OpenSSL.
  * Fixed XSS in homepage when displaying update check results (Sebastian Wolf)
  * Fixed allocation error in getcgi.c (#820) (Ariadne Conill)
  * Fixed Error: NULL variable for lines of spaces in resource.cfg (#814) (Ralf Herrmann)
  * Fixed crash when handling large check output (#825, #828) (Kilvador)
  * Update packaging instructions for RPM/EPEL (#850) (T.J. Yang)
  * Include packaging instructions for DEB (#842) (Catfriend1)
  * Fixed CGI object processing when names end in \ (#819) (Sebastian Wolf)
  * $SERVICEPROBLEMID$ now accessible when notifications are sent (#688) (Sebastian Wolf)
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * nagios-archive.service
  * nagios.service
* Mon May 10 2021 lars@linux-schulserver.de - 4.4.6
- new nagios-exec-start-post script to fix bsc#1003362
* Mon May 10 2021 lars@linux-schulserver.de - 4.4.6
- fix nagios_upgrade.sh writing to log file in user controlled
  directory (bsc#1182398). The nagios_upgrade.sh script writes the
  logfile directly below /var/log/
* Wed Jun  3 2020 Stefan Botter <obs@botter.cc>
- 4.4.6
  * Fixed Map display in Internet Explorer 11 (#714)
  * Fixed duplicate properties appearing in statusjson.cgi (#718)
  * Fixed NERD not building when enabled in ./configure (#723)
  * Fixed build process when using GCC 10 (#721)
  * Fixed postauth vulnerabilities in histogram.js, map.js, trends.js
  (CVE-2020-13977, bsc#1172794)
  * When using systemd, configuration will be verified before
  reloading (#715)
  * Fixed HARD OK states triggering on the maximum check attempt (#757)
* Mon Apr  6 2020 lars@linux-schulserver.de - 4.4.5
- fix boo#1156309, CVE-2019-3698 : Symbolic Link (Symlink) following
  vulnerability in the cronjob allows local attackers to cause cause
  DoS or potentially escalate privileges by winning a race.
- enhance systemd service: check nagios config before reloading
- enable build for SLE11 by excluding some special macros and
  directories via 'sles_version != 11' condition
- add nagios-archive.service and nagios-archive.timer as replacement
  for the script in cron.weekly: no need for cron on systemd systems
- run set_permissions and verifyscript for /etc/cron.weekly on those
  distributions that need it
- enhance rpmlint: ignore empty htpasswd file
- enable php apache module and not php5 on newer distributions
- try to harden the rcnagios script
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Fri Dec 20 2019 Stefan Botter <obs@botter.cc>
- 4.4.5
  * Reverted changes related to #625 due to CPU load issues
  * Partially reverted changes for #647 due to CPU load issues
  * Fixed "Quick Search" so that leading/trailing whitespace doesn't affect output (#681) (Sebastian Wolf)
  * Fixed build issues on non-RPM-based platforms (#617) (T.J. Yang)
- 4.4.4
  * Fixed log rotation logic to not repeatedly schedule rotation on a DST change (#610, #626) (Jaroslav Jindrak & Sebastian Wolf)
  * Fixed $SERVICEPROBLEMID$ to be reset after service recovery (#621) (Sebastian Wolf)
  * Fixed defunct worker processes appearing after nagios was reloaded (#441, #620) (Sebastian Wolf)
  * Fixed main nagios thread to release nagios.qh on a closed connection (#635) (Sebastian Wolf)
  * Fixed semicolon escaping to remove prepended backslash (\) (#643) (Sebastian Wolf)
  * Fixed 'Checks of this host have been disabled' message showing on passive-only hosts (#632) (Vojtěch Širůček & Sebastian Wolf)
  * Fixed last_hard_state showing the current hard state when service status is brokered (#633) (Sebastian Wolf)
  * Fixed long plugin output (>8KB) occasionally getting truncated (#625) (Sebastian Wolf)
  * Fixed check scheduling for objects with large check_intervals and small timeperiods (#647) (Sebastian Wolf)
  * Fixed SOFT recoveries sending when services had HARD recovery some time after host recovery (#651) (Sebastian Wolf)
  * Fixed incorrect permissions on debugging builds of FreeBSD (#420) (Sebastian Wolf)
  * Fixed NEB callback lists being partially orphaned when multiple modules subscribe to one callback (#590) (Sebastian Wolf)
  * Fixed memory leaks in run_async_service_check(), run_async_host_check() when checks are brokered (#664) (Sebastian Wolf)
  * Fixed potential XSS in main.php, map.php (#671, #672) (Jak Gibb)
  * Removed NEB brokering for nagios daemonization, since daemonization occurs before NEB initialization (#591) (Sebastian Wolf)
* Wed Nov 13 2019 Ansgar Esztermann <aeszter@gwdg.de>
- compile with -ffat-lto-objects to prevent build failure
* Tue Aug 20 2019 kukuk@suse.de
- Add /etc/cron.weekly to filelist, as this is now part of cron,
  which we don't want to require
* Sat Apr 20 2019 Stefan <obs@botter.cc>
- revert setting of sbindir back to nagios_cgidir
* Sun Jan 20 2019 obs@botter.cc - 4.4.3
- update to 4.4.3
  * Fixed services sending recovery emails when they recover if host in
  down state (#572) (Scott Wilkerson)
  * Fixed a make error when building on the aarch64 architecture (#598)
  (Gareth Randall)
  * Fixed --with-cgibindir and --with-webdir to actually set values given
  (#585) (lawsontyler)
  * Fixed soft recovery states for services (#575) (Jake Omann)
  * Fixed XSS vulnerability in Alert Summary report (CVE-2018-18245, boo#1119832)
  (Jake Omann)
  * Fixed services in soft states sometimes not switching into hard states
  (#576) (Jake Omann)
  * Fixed last_state_change to update when a state goes from soft -> hard
  state (#592) (Jake Omann)
  * Fixed Map link always being set to undefined host and don't show link
  for Nagios Process root note (#539) (Jake Omann)
  * Fixed notifications sending when services went into hard state on a
  down or unreachable host (#584) (Jake Omann)
  * Fixed log_host_retries not logging the host soft state checks (#599)
  (Jake Omann)
  * Fixed stalking_options N option to properly log only when a
  notification is actually sent (#604) (Jake Omann)
  * Fixed issue with service status totals being zero when
  servicegroup=all on servicegroup status page (#579) (Jake Omann)
  * Fixed escalation notifications logic and recovery notifications not
  going out (#582) (Jake Omann)
  * Fixed not finding child index causing duplicate hosts showing in the
  Map (#471) (Jake Omann)
  * Fixed Map configuration popup checkboxes not working and Root Node
  not populating (#543) (Jake Omann)
  * Fixed cleanup and deinit of neb modules on reload (#573) (Jake Omann)
- rebase nagios-4.2.2-enable-ppc64le.patch (allow ppc64le builds in
  contrib Makefile) to:
  nagios-4.4.3-enable-ppc64le.patch
* Mon Oct 15 2018 aeszter@gwdg.de
- install /var/spool/nagios setgid nagcmd so external applications
  like the webinterface can issue commands to nagios (boo#1028975)
* Mon Oct 15 2018 lars@linux-schulserver.de - 4.4.2
- update to 4.4.2
  * Fix comment data being duplicated after a `service nagios reload`
  or similar (#549) (Bryan Heden)
  * Fix check_interval and retry_interval not changing at the
  appropriate times (#551) (Scott Wilkerson)
  * Fixed passive checks sending recovery email when host was
  previously UP (#552) (Scott Wilkerson)
  * Fixed flapping comments duplication on nagios reload (#554)
  (Christian Jung)
  * Fix for CVE-2018-13441, CVE-2018-13458, CVE-2018-13457 null
  pointer dereference (Trevor McDonald) (boo#1101293, boo#1101289, boo#1101290)
  * Fixed syntax error in file: default-init.in (#558) (Christian Zettel)
  * Reset current notification number and state flags when the host recovers,
  reset all service variables when they recover fixes (#557) (Scott Wilkerson)
  * Fixed wrong counting of service status totals when showing
  servicegroup details (#548) (Christian Zettel, Bryan Heden)
  * Fixed avail.cgi not printing CSV output when checkbox is checked
  (for any type: host/service/hostgroup/servicegroup) (#570) (Bryan Heden)
  * Fixed nagios not logging SOFT state changes after 1 (Scott Wilkerson)
  4.4.1 - 2018-06-25
  * Revert some macro->kvvec changes causing problems when
  `enable_environment_macros` was enabled (Bryan Heden)
  * Adjust `process_macro_r` function logic so that it handles
  macros properly (Bryan Heden)
  * Fix spec file for systemd (Karsten Weiss, Fr3dY, Bryan Heden)
  * Fix bug where `ssize_t` typedef to int on some systems (Bryan Heden)
  4.4.0 - 2018-06-19
  ENHANCEMENTS
  * new status for check dependencies (John Frickson)
  * Allow more flexible requirements for comments (John Frickson)
  * Add a `statusCRITICALACK` class for the status column (John Frickson)
  * CSV output based on groups (all options) (John Frickson)
  * New Macro(s) to generate URL for host / service object to be
  used in notifications (John Frickson)
  * New Macro(s) to determine if host/service notifications are
  enabled (#419) (Bryan Heden)
  * New Macro(s) for obtaining the host/service notification
  periods (#350) (Bryan Heden)
  * enable_page_tour interface option (Bryan Heden)
  * Code cleanups in important sections (Workers, Handling Results) (Bryan Heden)
  * Automatic mail program detection (with same /bin/mail failback) (Bryan Heden)
  * Incorporated [autoconf-macros](https://github.com/NagiosEnterprises/autoconf-macros)
  into Core (Bryan Heden)
  * Lots of enhancements/additions to configure/make process. (Bryan Heden)
  + Moved all files to startup/
  + Added upstart job
  * Added system limit detection (RLIMIT_NPROC) to check for anticipated
  fork() failures (#434) (Bryan Heden)
  * Added stalking on notifications (`N` or `notifications` option when
  specifying `stalking_options`) (#342) (Bryan Heden)
  * Added automatic `systemctl daemon-reload` and `initctl reload-configuration`
  where applicable on `make install-init` (Bryan Heden)
  * Added case-insentive command submission. (#373) (Bryan Heden)
  * Enabled `check_external_commands` by default (Bryan Heden)
  FIXES
  * Command line macro detection skips potential macros with no ending
  dollar sign (Bryan Heden, Jake Omann)
  * Fixed a lockup condition sometimes encountered on shutdown or restart (Aaron Beck)
  * Fixed negative time offset calculations computing incorrectly sometimes (bbeutel)
  * Fixed reloads causing defunct (zombie) processes (#441) (Bryan Heden)
  * Fixed wait3(), wait4() implementations (replaced with waitpid()) (#326) (Bryan Heden)
  * Fixed additive inheritance not testing for duplicates in
  hosts/services/(+escalations) (#392) (Bryan Heden)
  * Fixed very very (around 600k chars or greater) large plugin
  output crashing Nagios (#432) (Bryan Heden)
  * Fixed first_notification_delay not beeing calculated from
  last_hard_state_change (#425) (Christian Zettel)
  * Fixed duplicate downtime ID occuring from downtimes in retention
  file (#506) (Franz [feisenko])
  * Fixed segfault when navbarsearch was used in status.cgi for something
  other than a host (#489) (Bryan Heden)
  * Fixed some miscellaneous ./configure issues on Solaris (Bryan Heden, Troy Lea)
  * Fixed "Locate host on map" link (#496) (Troy Lea)
  * Fixed service groups defined with unknown service members
  (that aren't first in the list) not erroring out (#500) (Bryan Heden)
  * Fixed tac.cgi to have consistent behavior with the other cgis (#481)
  (Bryan Heden, Matt Capra)
  * Fixed clear_host/service_flapping command logic to broker/notify
  properly (#525) (Bryan Heden, Karsten Weiss)
- removed upstreamed patches:
  + nagios-fix_spurious_dollar_signs_added_to_command_lines.patch
  + nagios-4.3.4-fix_memleak_4.3.3.diff
- refreshed patches:
  + nagios-4.0.6-remove-date-time.patch
  + nagios-4.1.0-add_KOHANNA.conf
  + nagios-4.2.2-enable-ppc64le.patch
  + nagios-disable_phone_home.patch
  + nagios-fix_encoding_trends.cgi.patch
  + nagios-output-length.patch
  + nagios-random_data.patch
* Tue Jun  5 2018 adaugherity@tamu.edu
- fix setting default values in nagios-exec-start-pre
* Thu Mar  8 2018 crrodriguez@opensuse.org
- remove unused xorg-x11-devel BuildRequires
* Tue Jan 30 2018 obs@botter.cc
- fix upstream issue #455, memleak introduced with 4.3.3
  nagios-4.3.4-fix_memleak_4.3.3.diff
* Fri Dec  1 2017 lars@linux-schulserver.de
- update to 4.1.0 fixed boo#939829 already, mentioned here just
  for reference
* Fri Dec  1 2017 lars@linux-schulserver.de
- fix a possible symlink attack for files/dirs created by root
  fixes CVE-2016-8641 (bsc#1011630 and bsc#1018047)
- remove the pre-configured administrative account with fixed
  password from the htpasswd file and provide an empty one instead
  (fixes boo#961115 - CVE-2016-0726)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Oct 12 2017 sbrabec@suse.com
- Do not introduce new RPM group just for nagios-contrib.
  Use established Development/Tools/Other instead.
* Wed Sep 13 2017 lars@linux-schulserver.de
- update to 4.3.4
  * Improved config file parsing (Mark Felder)
  * Fixed configure script to check for existence of /run for lock
    file (in regards to CVE-2017-12847, Bryan Heden)
  * Use absolute paths when deleting check results files (Emmanuel Dreyfus)
  * Add sanity checking in reassign_worker (sq5bpf)
  * xodtemplate.c wrong option-deprecation code warning (alex2grad / John Frickson)
  * On-demand host check always use cached host state (John Frickson)
  * 'á' causes Serivce Status Information to not be displayed (John Frickson)
  * New Macro(s) to generate URL for host / service object (John Frickson)
  * Fix minor map issues (Troy Lea)
  * Fix lockfile issues (Bryan Heden)
  * Switch order of daemon_init and drop_priveleges (CVE-2017-12847, Bryan Heden)
  * Add an OpenRC init script (Michael Orlitzky)
- only require insserv on older SUSE distributions
* Wed Jun  7 2017 lars@linux-schulserver.de
- update to 4.3.2
  FIXED
  * Every 15sec /var/log/messages is flooded with
    "nagios: set_environment_var" (John Frickson)
  * Changed release date to ISO format (yyyy-mm-dd) (John Frickson)
  * `make all` fails if unzip is not installed (John Frickson)
  * Quick Search no longer allows search by Alias (John Frickson)
  * flexible downtime on a service immediately turns off notifications
    (John Frickson)
  * Fix to allow url_encode to be called twice (Z. Liu)
  * Update timeperiods.cfg.in (spelling) (Parth Laxmikant Kolekar)
  * Spelling fixes (Josh Soref)
  * Vent command pipe before remove to avoid deadlocks on
    writing end (Kai Kunstmann)
  * CGI utility cgiutil.c does not process relative config file
    path names properly (John Frickson)
  * xdata/xodtemplate.c bug in option-deprecation code (John Frickson)
  * Wildcard searching causes service status links to not work properly
    (John Frickson)
  * Quick search with no hits shows a permission denied error (John Frickson)
  * Setting a service as its own parent is not caught by the sanity
    checker (-v) and causes a segfault (John Frickson)
- removed nagios-4.3.1-remove-flooding-messages.patch (fixed upstream)
* Mon Mar  6 2017 obs@botter.cc
- fix upstream issue #337: remove debugging messages:
  nagios-4.3.1-remove-flooding-messages.patch
* Fri Feb 24 2017 lars@linux-schulserver.de
- Update to 4.3.1
  SECURITY FIXES
  * Fix for CVE-2016-6209 (bsc#989759) - The "corewindow" parameter (as in
    http://localhost/nagios?corewindow=www.somewhere.com) has been disabled by
    default. See the UPGRADING document for how to enable it. (John Frickson)
  FIXES
  * Service hard state generation and host hard or soft down status (John Frickson)
  * Comments are duplicated through Nagios reload (John Frickson)
  * host hourly value is incorrectly dumped as json boolean (John Frickson)
  * Bug - Quick Search no longer allows search by IP (John Frickson)
  * Config: status_update_interval can not be set to 1 (John Frickson)
  * Check attempts not increasing if nagios is reloaded (John Frickson)
  * nagios hangs on reload while sending external command to cmd file (John Frickson)
  * Feature Request: return code xxx out of bounds - include message as well (John Frickson)
  * Fix early event scheduling (pmalek / John Frickson)
  * on-demand host checks triggered by service checks cause attempt number increments (fredericve)
  * Service notification not being send when host is in soft down state (John Frickson)
  * configure does not error if no perl installed on CentOS 7 (John Frickson)
  * failed passive requests leave .ok files in checkresults dir (caronc)
  * Services don't show in status.cgi if "noheader" specified (John Frickson)
  * Standardized check interval config file names (John Frickson)
  * "Event Log" (showlog.cgi) could not open log file (John Frickson)
  * "nagios_check_command" has been deprecated since v3.0. Last vestiges
    removed (John Frickson)
  ENHANCEMENTS
  * Added new flag to cgi.cfg: tac_cgi_hard_only to show only HARD
    states (John Frickson)
  * Add broker-event for the end of a timed event (NEBTYPE_TIMEDEVENT_END) (John Frickson)
  * There is no Macro to retrieve addresses of hostgroup members
    (now $HOSTGROUPMEMBERADDRESSES$) (John Frickson)
  * Add "Page Tour" videos to several of the core web pages (John Frickson)
  * Added a login page, and a `Logoff` links (John Frickson)
  * On the status map, the host name will be colored if services are
    not all OK. (John Frickson)
  * Added "Clear flapping state" command on host and services
    detail pages. (John Frickson)
  * User-entered comment now displays below generated comment for
    downtime (John Frickson)
- refreshed patches
* Sun Dec 11 2016 lars@linux-schulserver.de
- update to 4.2.4
  SECURITY FIXES
  * Fixed another root privilege escalation (CVE-2016-9566) Thanks for
    bringing this to our attention go to Dawid Golunski (bsc#1014637)
    (http://legalhackers.com).
* Tue Nov 29 2016 lars@linux-schulserver.de
- update to 4.2.3
  SECURITY FIXES
  * Fixed a root privilege escalation (CVE-2016-8641) (John Frickson)
  FIXES
  * external command during reload doesn't work (John Frickson)
  * Nagios provides no error condition as to why it fails on the
    verify for serviceescalation (John Frickson)
  * No root group in FreeBSD and Apple OS X (John Frickson)
  * jsonquery.html doesn't display scheduled_time_ok correctly (John Frickson)
  * daemon_dumps_core=1 has no effect on Linux when Nagios
    started as root (John Frickson)
  * Configuration check in hostgroup - misspelled hostname does
    not error (John Frickson)
  * contacts or contact_groups directive with no value should not
    be allowed (John Frickson)
  * Compile 64-bit on SPARC produces LD error (John Frickson)
  * HOSTSTATEID returns 0 even if host does not exist (John Frickson)
  * Submitting UNREACHABLE passive result for host sets it as DOWN
    if the host has no parents (John Frickson)
  * nagios: job XX (pid=YY): read() returned error 11 (changed from
    LOG_ERR to LOG_NOTICE) (John Frickson)
  * Fix for quick search not showing services if wildcard used
    (John Frickson)
* Wed Nov  9 2016 jengelh@inai.de
- use faster find variants
* Tue Nov  8 2016 lars@linux-schulserver.de
- allow ppc64le builds in contrib Makefile:
  nagios-4.2.2-enable-ppc64le.patch
* Tue Oct 25 2016 lars@linux-schulserver.de
- update to 4.2.2
  SECURITY
  + There was a fix to vulnerability CVE-2008-4796 in the 4.2.0 release
    on August 1, 2016. The fix was apparently incomplete, as there was
    still a problem. However, we are now getting all RSS feeds using AJAX
    calls instead of the (outdated) MagpieRSS package. Thanks for bringing
    this to our attention go to Dawid Golunski (http://legalhackers.com).
  ENHANCEMENTS
  + Update status.c to display passive check icon for hosts when
    passive checks are enabled and actives disabled
  FIXES
  + Fix permissions for Host Groups reports (status.cgi)
  + Service Parents does not appear to be functioning as intended
  + Availability report mixes up scheduled and unscheduled warning percentages
  + Invalid values for saved_stamp in comput_subject_downtime_times()
  + Remove deprecated “framespacing”
  + The nagios tarball contains two identical jquery copies
  + extinfo.cgi does not set content-type (most cgi’s don’t)
  + Timeperiods are corrupted by external command CHANGE_SVC_CHECK_TIMEPERIOD
  + Quick search doesn’t show hosts without services (service status detail page)
  + In host/services details view, if exactly 100 entries would not show last one
  + nagios host URL parameter for NEW map doesn`t work – Network Map for All Hosts
  + next_problem_id is improperly initialized
  + Passive problems not showing as “unhandled”
  + September reported as Sept instead of Sep
  + Notifications are not sent for active alerts after scheduled downtime ends
  + Nagios 4.2.0 not working on Solaris
  + install-exfoliation and install-classicui don’t work FreeBSD and Mac OS X
  + Updated makefile to delete some no-longer-needed files
* Tue Sep  6 2016 lars@linux-schulserver.de
- update to 4.2.1
  FIXES
  + Fix undefined variable php error (John Frickson)
  + Links on the sidebar menu under 'Problems' are indented too far
  + Using $ARGn$ Macros in perfdata (John Frickson)
  + using a wildcard in search returns service status total all zero's
  + read_only does not take priority (deppy)
  + Running nagios -v on 4.2.0 takes 90+ seconds (John Frickson)
  + Missing Image for Host and Service State Trends in Availability Report
  + Maintain non-persistent comments through reload (John Frickson)
  + Servicegroup availability report ignores includesoftstates in
    service report links (PriceChild)
  + error: format not a string literal and no format arguments (Karsten Weiss)
- ignore rpmlint warnings about tmpfile creating/listing: this is
  handled, but not properly detected by rpmlnt
* Fri Sep  2 2016 lars.vogdt@suse.com
- update to 4.2.0
  SECURITY FIXES
  + Fixed vulnerability CVE-2008-4796 (John Frickson)
  + Fixed vulnerability CVE-2013-4214 (John Frickson)
  + web interface vulnerable to Cross-Site Request Forgery attacks
  ENHANCEMENTS
  + Increase socket queue length for listen()
  + Added host name to the website page title (leres / John Frickson)
  + Added additional icons for NetBSD and SuSE (John Frickson)
  + The new Status Map will now use cgi.cfg options (John Frickson)
    default_statusmap_layout will default to "6" for the new map
  + The new Status Map will now show some valid values in the
    popup for "Nagios Process" (John Frickson)
  FIXES
  + Network outage view without access to all hosts (John Frickson)
  + Core workers looping (John Frickson)
  + service query returns duplicate host_name and description
    fields in the returned data (John Frickson)
  + HTML output of plug-ins is parsed in wrong way => webgui
    unusable (John Frickson)
  + Command worker fails to handle SIGPIPE
  + "View Status" links under "Map" broken in Nagios Core
    Version 4.1.1 (John Frickson)
  + Can't send big buffer - wproc: Core Worker seems to be choked
  + Too big CPU load on FreeBSD and other systems using poll() interface
  + Flexible downtime recorded as unscheduled downtime (John Frickson)
  + Service Flexible downtimes produce 1 notification before entering
  + Once you "set flap_detection_enabled 0" it should remove flapping
    state from the host/services page (John Frickson)
  + New map doesn't finish loading if a logo image is not found
  + Extraneous Div end tag in map.html (Scott Wilkerson)
  + Issue with "Problems" section (John Frickson)
  + Status Map icons and online/offline status dots disappear in IE11
  + New network map overlays the nagios process with objects
  + Added Default-Start and Default-Stop to the init script
  + Compile / logging issues with BSD 6
  + Related to above, Fixed a lot of incorrectly handled
    time_t's in *printf's
  + New map not working for RU locale (actually, most locales)
  + Replaced all instances of signal() with sigaction() + blockig
  + UTF-8 characters like german ä are not processed properly by
    function url_encode (John Frickson)
  + nagios worker processes can hog CPU (huxley / John Frickson)
  + custom time periods that include special characters were not
    being handled in reports (John Frickson)
  + Fixed init script to wait up to 90 seconds then kill the
    nagios process (John Frickson)
  + No Host Groups results in wrong error message (John Frickson)
  + Setup Nagios users to view specific host is not working in the
    new network map (John Frickson)
  + statusjson.cgi fails glibc realloc truncate response output (John Frickson)
  + Report Time Period does not work if an @ character is in
    the timeperiod name (John Frickson)
  + State History does not use actual plugin long_output (John Frickson)
  + Time period corruption (xoubih)
  + Tactical Overview - Disabled Flap Detection Link (John Frickson)
- add /var/run/nagios as ghost directory
* Fri Oct 16 2015 adaugherity@tamu.edu
- Fix nagios-www: keep nagios-www-dch from owning html files shipped with
  Nagios.
- Remove unused NAGIOSDCH apache flag.
* Mon Sep 21 2015 aj@ajaissle.de
- Update to 4.1.1
  FIXES
  * CGI Could not read object configuration data (broken by error in 4.1.0)
  * exclude (!) not working (broken by mis-applied fix for 4.1.0)
- Dropped patch nagios-issue_71.patch (included in sources)
* Wed Sep  2 2015 archie@dellroad.org
- Add nagios-issue_71.patch
  * Fixes "CGI Could not read object configuration data" (boo#944102)
* Thu Aug 20 2015 lars@linux-schulserver.de
- add nagios-4.1.0-add_KOHANNA.conf patch to allow using kohanna2
  if available
* Wed Aug 19 2015 lars@linux-schulserver.de
- update to 4.1.0:
  ENHANCEMENTS
  * Promoted JSON CGIs to released status
  * New graphical CGI displays: statusmap, trends, histogram
  * Make sticky status for acks and comments configurable enhancement #20
  * Add host_down_disable_service_checks directive to nagios.cfg #44
  * httpd.conf doesn't support Apache versions > 2.3
  FIXES
  * Fix for not all service dependencies created (John Frickson)
  * Fix SIGSEGV with empty custom variable (orbis / John Frickson)
  * Fix contact macros in environment variables (dvoryanchikov)
  * Fixed host's current attempt goes to 1 after going to hard state
  * Fixed two bugs/problems: Replace use of %%zd in base/utils.c &
    incorrect va_start() in cgi/jsonutils.c (Peter Eriksson)
  * Fixed: Let remove_specialized actually remove all workers (Phil Mayers)
  * Fixed log file spam caused when using perfdata command directives in nagios.cfg
  * Fixed off-by-one error in bounds check leads to segfault (Phil Mayers)
  * Added links for legacy graphical displays (Eric Stanley)
  * Update embedded URL's to https versions of Nagios websites
  * Fixed doxygen comments to work with latest doxygen 1.8.9.1 #30
  * Fixed makefile target "html" to PHONY to fix GitHub issue #28
  * Fixed typo as per GitHub issue #27 (Trevor McDonald)
  * Fixed jsonquery.php 404 not found error, and disabled Send Query
    button until form populates #43
  * Fixed linking in Tactical Overview for several of the Host entries
    in Featured section #48
  * Fixed passing limit and sort options to pagination and sort links #42
  * Added form field for icon URL and clean-up when it changes in CGI Status Map.
  * Added options to cgi.cfg to uncheck sticky and send when acknowledging a problem
  * Low impact changes to automate the generation of RPMs from nagios.spec file.
  * Update index.php (Trevor McDonald)
  * Fixed escaping of corewindow parameter to account for possible XSS injection
  * Typo correction (T.J. Yang)
  * Make getCoreStatus respect cgi_base_url (Moritz Schlarb)
  * Adjusted map layout to work within frames (Eric Stanley)
  * Fixed map displays are now the full size of browser window (Eric Stanley)
  * Fixed labels and icons on circular markup no longer scale on zoom
  * Got all maps except circular markup working with icons (Eric Stanley)
  * Fixes to make legacy CGIs work again. (Eric Stanley)
  * Fixes to make all/html target tolerant of being run multiple times
  * For user-supplied maps, converted node group to have transform
  * Fixed issue transitioning from circular markup map to other maps
  * Fix displayForm to trigger on the buttom press (Scott Wilkerson)
  * Fix fo getBBox crash on Firefox (Eric Stanley)
  * Fixed map now resets zoom when form apply()'d (Eric Stanley)
  * Fixed so close box on dialogs actually closes dialog (Eric Stanley)
  * Corrected directive in trends display (Eric Stanley)
  * Fixed minor issue with link in trends linkes (Eric Stanley)
  * Fixed issue with map displaying on Firefox (Eric Stanley)
  * Added exclusions for ctags generation (Eric Stanley)
  * Update map-popup.html (Scott Wilkerson)
  * Initial commit of new graphical CGIs (Eric Stanley)
  * Fixed Github bug #18 - archivejson.cgi returns wrong host for state
    change query (Eric Stanley)
  * Status JSON: Added next_check to service details (Eric Stanley)
  * Fixed escaping of keys for scalar values in JSON CGIs (Eric Stanley)
  * build: Include <sys/loadavg.h> if it exists. (Eric J. Mislivec)
  * lib-tests: test-io{cache|broker} need -lsocket to link. (Eric J. Mislivec)
  * lib-tests: test-runcmd assumes GNU echo. (Eric J. Mislivec)
  * lib-tests: Signal handlers don't return int on most platforms, and using
    a cast was the wrong way to resolve this. (Eric J. Mislivec)
  * Fix some type/format mismatch warnings for pid_t. (Eric J. Mislivec)
  * Fix build on Solaris. (Eric J. Mislivec)
  * runcmd: Fix build when we don't HAVE_SETENV. (Eric J. Mislivec)
  * Fixed checkresult output processing (Eric Mislivec)
  * Corrected escaping of long output macros (Eric Mislivec)
  * Fixed null pointer dereferences in archive JSON (Eric Stanley)
  * Fixed memory overwrite issue in JSON string escaping (Eric Stanley)
  * JSON CGI: Now escaping object and array keys (Eric Stanley)
  KNOWN ISSUES
  * New map does not account for multiple parents, leaving "legacy"
    map as an option in the menu
- removed upstreamed patches:
  + nagios-bogus_warnings.patch
  + nagios-apache24.patch
- refreshed all other patches
* Fri Jul 31 2015 pgajdos@suse.com
- use new syntax for apache 2.4
  + nagios-apache24.patch
* Fri Feb 27 2015 darin@darins.net
- patch so nagios does not truncate performace data
* Tue Feb 17 2015 lars@linux-schulserver.de
- fix alias definition in systemd file
* Mon Feb 16 2015 lars@linux-schulserver.de
- ignore errors during *post* of nagios-theme-exfoliation caused
  by the script trying to restart apache during build (bnc#911755)
- ignore suse-missing-rclink rpmlint warning, as we use a wrapper
  script to provide backward compatible features (check)
* Wed Jan 28 2015 lars@linux-schulserver.de
- add Alias=monitoring_daemon.service to systemd file to have a
  similar virtual provides like in the old times
* Thu Dec  4 2014 lars@linux-schulserver.de
- package a shell script in /usr/sbin/rcnagios providing the
  check commands as in the old sysvinit days (and redirect anything
  else directly to systemctl)
* Fri Aug 15 2014 lars@linux-schulserver.de
- update to 4.0.8:
  ENHANCEMENTS
  * Removed 8 kB string size limitation in JSON CGIs (Eric Stanley)
  * Re-implemented auto-rescheduling of checks (Eric Mislivec)
  * Avoid bunching of checks delayed due to timeperiod constraints
  * Limit the number of autocalculated core workers to not spawn
    too many on large systems (Eric Mislivec, Janice Singh)
  FIXES
  * Removed quotes from numeric duration values in JSON CGIs
  * Fixed escaping in JSON CGIs so all required characters are
    escaped, and in the correct order (Eric Stanley)
  * Fixed segfault in archive JSON CGI when plugin output was empty
  * Fixed several possibilities for buffer overflow
  * Fixed Tracker #582, #626: Handle VAR=VAL assignments at the start
    of simple commands (Eric Mislivec, Phil Randal)
  * Fixed Tracker #630: Recognize '<' and '>' as redirection operators
  * Corrected worker communication protocol documentation
  * Fixed Tracker #361: Downtime notifications not displayed properly
- removed nagios-CVE-2014-1878.patch (fixed upstream)
- refreshed all patches
* Wed Jul 23 2014 lars@linux-schulserver.de
- include special handling for the temp_path variable in the
  nagios-exec-start-pre script to avoid setting wrong permissions
  (bnc #887904)
* Wed Jun 25 2014 wagner-thomas@gmx.at
- Patch away bogus warnings "Unknown jobtype: 10" flooding log files
  if service_perfdata_command is used.
  This patch implements the fix of the upstream bugreport #534
  See http://tracker.nagios.org/view.php?id=534 for details.
  => bogus_warnings.patch
* Thu Jun  5 2014 lars@linux-schulserver.de
- use systemctl on newer distributions (bnc #881289)
* Tue Jun  3 2014 lars@linux-schulserver.de
- update to 4.0.7:
  ENHANCEMENTS
  * Added value of custom variables to Object JSON output for hosts,
    services and contacts (Eric Stanley)
  FIXES
  * Fixed bug #616: Unescape plugin output read from checkresult files,
    fix multiline perf data concatenation, and avoid extra memory
    allocation and copies. (Eric Mislivec)
  * Fixed bug #609: Image on home page doesn't have correct image
    path prefix. (Derek Brewer)
  * Fixed bug #608: Extra newline in service check timeout
    output string. (Mauno Pihelgas)
  * Fixed bug #596: Crashes checking contact authorization for host
    escalations. (Alexey Dvoryanchikov - duplicates #590, #586)
  * Fixed bug #496: Syntax error in exfoliation's common.css.
    (Karsten Weiss)
* Sat May  3 2014 lars@linux-schulserver.de
- update to 4.0.6:
  ENHANCEMENTS
  * Added name of authenticated user to JSON CGI results object
  * Added Nagios Core version to the Status JSON CGI programstatus query
  * Added daemon status to main page
  FIXES
  * Fixed bug #600: Service Check Timeout State always returns OK (0) status
  * Fixed bug #583: Status Check Output of (No output on stdout) stderr
  * Fixed bug #573: Service checks returns (No output on stdout) stderr
  * Fixed bug #438: Reloads during downtime causes wrong availability
    calculations
  * Fixed feed updates when daemon can not access external networks
  * Archive JSON: Fixed bugs calculating availability
  * Archive JSON: Allow missing logs to be skipped
- refreshed patches to apply with latest source
* Sat Apr 12 2014 lars@linux-schulserver.de
- update to 4.0.5:
  + Fixed bug #595: Nagios 4 security fix
  + Fixed bug #594: Nagios 4 fix contactgroups parsing
  + Fixed bug #577: Nagios 4 checks stalled when write to socket failed
  + Fixed bug #580: Nagios 4 memory leak
  + Fixed bug where audio alerts wouldn't work with a 0 height and
    width - http://support.nagios.com/forum/viewtopic.php?t=26387
* Fri Mar 28 2014 lars@linux-schulserver.de
- fix stack-based buffer overflow in the cmd_submitf function
  in cgi/cmd.c - CVE-2014-1878 (bnc#864843)
  nagios-CVE-2014-1878.patch
* Mon Mar 17 2014 andreas.stieger@gmx.de
- add nagios-4.0.4-remove-date-time.patch to prevent unneccessary
  rebuilds due to __DATE__ and __TIME__ macros
* Sun Mar 16 2014 lars@linux-schulserver.de
- update to 4.0.4:
  ENHANCEMENTS
  * JSON CGIs moved to beta status (Eric Stanley)
  FIXES
  * Fixed bug #491,#553: Rebuilt the daemon-init scripts back to
    something that should work on all systems (Scott Wilkerson)
* Sat Mar  1 2014 lars@linux-schulserver.de
- update to 4.0.3
  ENHANCEMENTS
  * Aliased hourly_value to importance and minimum_value to
    minimum_importance and deprecated the former (Eric Stanley)
  * Added host and service importance macros (Eric Stanley)
  * Added notifications on flexible downtime expiration (Dan Wittenberg)
  FIXES
  * Bug #548: Temporary fix that rejects all external command during
    restart to prevent Core from crashing (Eric Stanley)
  * Corrected calculation of host importance and importance defaults (Eric
    Stanley)
  * Fixed bug #498: Nagios 4 enable_environment_macros=1 not working (Eric
    Stanley, Alexey Dvoryanchikov)
  * No longer checks whether logs can be written when verifying
    configuration (Eric Stanley)
  * Fixed CGI bug where the CGI could read past the end of the list of CGI
    variables, potentially crashing the CGI (Scott Wilkerson)
  * Fixed inheritance of hourly_value from host and service templates
    (Scott Wilkerson)
  * Fixed bug #502: 4.0.0: Configuration -> Service Escalations =
    incomplete list (Eric Stanley)
  * Fixed bug #523: quotes and double quotes in plugin message are
    converted to HTML escapes in Nagios 4.0 (duplicate of bug #524)
  * Fixed bug #524: URLs returned in plugin check results are not
    correctly displayed (Eric Stanley)
  * Fixed bug where passive service checks would return "Service check
    timed out after 0.00 seconds" (Scott Wilkerson)
- print recommendation to run the upgrade_nagios script in case
  of an update (via logger command)
- added man page for nagios_upgrade
* Fri Jan 24 2014 lars@linux-schulserver.de
- update to 4.0.2
  FIXES
  * Fixed 528: Nagios 4.0.1: Logrotation: Only current host- and
    servicestates saved in rotated logfiles (duplicate of 507)
  * Fixed 507: Nagios 4.0.0 - Problem during log rotate (Stefano Ghelfi)
  * Fixed 530: RPM spec file sets wrong permissions on plugins
    directory (duplicate of bug 494)
  * Fixed 494: nagios.spec fixes (with patch) (Karsten Weiss)
  * Fixed 515: Segsegv after starting up nagios (duplicate of bug 526)
  * Fixed 513: Crash while entering downtime for service
    (duplicate of bug 526)
  * Fixed 529: Core Worker failed to reap child in 4.0.1 Description
  * Fixed 514: scheduled downtime not showing in web interface
    (Eric Stanley)
  * Fixed 526: sort_downtime() corrupts scheduled_downtime_list
    causing segfault (Adam James)
  * Fixed 492: Nagios 4 fails to remove/add checks upon reload
    (Eric Stanley)
  * Fixed 484: Beta4.0.0b4 service checks returning (No output
    on stdout) (Eric Stanley)
  * Fixed 470: statusmap doesn't display info (Cameron Moore)
  * Fixed 499: Security issue in daemon-init.in, function
    check_config (Tómas Edwardsson)
* Thu Jan 23 2014 lars@linux-schulserver.de
- update to 4.0.1
  ENHANCEMENTS
  * Added compiler flags in RPM spec file to reduce compiler noise
    (Dan Wittenberg)
  * Added logging of failure in dlclose() call (Anton Lofgren)
  * Added a simple query handler interface, nagios-qh.rb
    (Dan Wittenberg)
  * Multiple code simplifications, additional error handling in
    downtime code (Andreas Ericsson)
  FIXES
  * Reverted commit f99a9a7b which set check_interval to 1 if
    it was configured as zero.
  * Corrected order of arguments when logging unknown hosts/services
    (Scott Wilkerson)
  * Downtime initialized before retention data read (Eric Stanley)
  * Patches to make RPM build again (Dan Wittenberg)
  * Ensure that scheduled_downtime_depth never drops below zero
    (Andreas Ericsson)
  For a complete list of changes for the new Nagios Core 4 version,
  see http://nagios.sourceforge.net/docs/nagioscore/4/en/whatsnew.html
- removed upstreamed patches:
  + nagios-CVE-2013-2214.patch
  + nagios-disable_phone_home.patch
  + nagios-p1.pl-location.patch
- added nagios-random_data.patch
* Wed Jan 22 2014 obs@botter.cc
- bring package back to compiling state after introducing
  incompatible changes in nagios.spec with submit from
  Dec 27th (spec file changes obviously already for nagios 4.0,
  whereas we are still at 3.5.1).
* Fri Dec 27 2013 lars@linux-schulserver.de
- Fix possible denial of service in CGI executables:
  * nagios-CVE-2013-7108.patch (bnc#856837)
* Tue Sep 24 2013 lars@linux-schulserver.de
- cleanup file list
* Wed Sep 11 2013 lars@linux-schulserver.de
- Recommend monitoring-tools package for those who want to convert
  their (real old) nagios configuration (using the subpackage from
  icinga)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Fri Aug 30 2013 schneemann@b1-systems.de
- update to 3.5.1:
  + Added handler for SIGXFSZ signal (Eric Stanley)
  + Fixed bug #444: Nagios 3.5.0 problem with macro $ADMINEMAIL$ :
    @ is converted to %%40 after 2 nagios reload (Duplicate of bug #407)
  + Fixed bug #407: Reloading nagios config causes spaces in notifications
    to become plus signs (Alexey Dvoryanchikov)
  + Fixed bug #445: Adding triggered downtime for child hosts causes a
    SIGSEGV on restart/reload (Eric Stanley)
  + Fixed bug #375: Freshness expiration never reached and bug #427:
    freshness threshold doesn't work if it is set long
    (Scott Wilkerson, Eric Stanley)
  + Fixed bug #432: Downtime scheduled as "Nagios Process" and not
    the Users name (Sam Lansing, Eric Stanley)
* Fri Jul 26 2013 thardeck@suse.com
- added icinga-monitoring-tools as recommend and removed the duplicated nagios files
* Fri Jun 28 2013 lars@linux-schulserver.de
- added nagios-CVE-2013-2214.patch fixing unauthorized host/service
  views displayed in servicegroup view (bnc#827020)
* Thu Jun 27 2013 lars@linux-schulserver.de
- fix permission problem on /usr/lib/nagios/plugins introduced with
  one of the latest updates
* Sun Mar 17 2013 lars@linux-schulserver.de
- adapt static html pages to reflect the current version
* Sat Mar 16 2013 schneemann@b1-systems.de
- update to 3.5.0:
  + Fixed bug #403: The "configuration" page of the webui doesn't use
    entity encoding when displaying the "command expansion" item (Eric
    Stanley, Phil Randal)
  + Fixed bug #424: Nagios Core 3.4.4 seg fault (core dump) on restart
    after removing config for running service (Eric Stanley)
  + Updated CGI utility functions to support UTF-8 characters (Eric Stanley)
  + Fixed bug where selecting Command Expansion from Configuration CGI
    page would display commands instead (Eric Stanley)
  + Fixed bug #369: status.cgi crashes with segfault when there are german
    ulauts (äöüß) in the hostname or the servicename (Eric Stanley)
  + Fixed bug #418: Scheduled Downtime Notifications Resent On Nagios
    Restart/reload (Eric Stanley
* Wed Mar 13 2013 lars@linux-schulserver.de
- general update for 12.1, 12.2 and 12.3 for bnc#809180
* Thu Feb 14 2013 lars@linux-schulserver.de
- provide 'monitoring_daemon' in the init script to allow other
  init scripts to depend on it
* Sat Jan 12 2013 lars@linux-schulserver.de
- update to 3.4.4:
  + Fixed bug #408: service checks get duplicated on reload (Eric Stanley)
  + Added NULL pointer checks to CGI code. (Eric Stanley)
  + Fixed buffer overflow vulnerability in CGI code. Thanks to Neohapsis
    for finding this. (Eric Stanley)
- refreshed patches
* Wed Jan  9 2013 lars@linux-schulserver.de
- added new subpackage nagios-www-dch (don't call home):
  + add plain html pages to allow users to disable PHP and
    loading of external references
  + re-added documentation (no external link any more)
* Tue Jan  1 2013 lars@linux-schulserver.de
- use new rpm macros for basic user-/groupadd commands:
  %%%%nagios_user_group_add
  %%%%nagios_command_user_group_add
* Mon Dec 17 2012 lars@linux-schulserver.de
- update to 3.4.3:
  * Applied fix for pagination and sorting on status.cgi #381
    (Phil Randal)
  * Fixed issue where deleting a downtime could cause Nagios to crash
    (Eric Stanley)
  * Corrected logic so that end times for flexible downtimes are
    calculated from the downtime start rather than the current time
    in the case where Nagios is restarted (Eric Stanley)
  * Fixed issue introduced by fix for bug #124 where flexible
    downtimes are not taken into account on Nagios restart.
    (Scott Wilkerson, Eric Stanley)
  * Fixed bug #247: If a service reports no performance data, the
    perfdata log file has no line indicating the test.
    (omnikron@free.fr)
  * Fixed link for unhandled unreachable host problems on tactical
    overview page (Rudolf Cejka)
  * Fixed bug #345 with wild card searches not paging properly
    on status.cgi (Phil Randal)
  * Fixed bug #343 on status.cgi where Service Group Summary can
    potentially show wrong totals (Mark Ziesemer)
  * Fixed memory leaks on SIGHUP (Carlos Velasco)
- refreshed patches
- just require php not php5 to allow a switch to php53
- do not compress logfiles per default to allow searching via
  webinterface
- init script now uses daemonchk.cgi to check for status (if present)
* Mon Nov 26 2012 aeszter@gwdg.de
- Use usermod instead of groupmod when suse_version > 1220 due to
  pwdutils/shadow switch.
* Tue Nov 20 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Thu Oct 11 2012 lars@linux-schulserver.de
- add virtual provides 'monitoring_daemon' and
  'monitoring_webfrontend' to allow 3rd party packages to run also
  with compatible solutions like icinga
* Sun Jun 10 2012 lars@linux-schulserver.de
- remove checks.c-declare-temp_buffer.patch again as this is
  fixed with the latest version
- added manpages for {new,}mini_epn and convertcfg
* Sun Jun  3 2012 ro@suse.de
- update to 3.4.1
  * Double quotes in check_command definition break functionality
  (#332, reverts #86)
* Wed May 23 2012 lars@linux-schulserver.de
- run config check first before restart (init script)
- ignore subsys-unsupported rpmlint check as the init script just
  removes it
* Mon May  7 2012 schneemann@b1-systems.de
- update to 3.4.0
  * Use execv() to execute active check commands (#86 - Ton Voon, dnsmichi)
  * Added service_check_timeout_state configuration variable (Bill McGonigle)
  * Permanently remove sleep on run_event == FALSE in main loop (Max
    <perldork@webwizarddesign.com>)
  * Reduce notification load by moving notification viability check into
    notification list creation (Opsview Team)
  * Added code to apply allow_empty_hostgroup_assignment flag to host and
    service dependencies (Daniel Wittenberg)
  * Users can now see hostgroups and servicegroups that contain at least
    one host or service they are authorized for, instead of having to be
    authorized for them all (Ethan Galstad)
  * RSS feed boxes fallback if an error occurs (Ethan Galstad)
  * RSS feeds no longer block main page load (Mike Guthrie)
  FIXES
  * Fix $NOTIFICATIONRECIPIENTS$ macro to contain all contacts assigned to
    host|service, not only notified contacts (Bug #98 Matt Harrington)
  * Scheduled Downtime Notifications Resent On Nagios Restart/reload (Bug
    [#124] - ricardo)
  * NOTIFICATIONTYPE MACRO never became CUSTOM (Bug #168 - Alexey
    Dvoryanchikov)
  * Plugged minor memory leaks in notification logic
* Wed Dec  7 2011 chris@computersalat.de
- fix p1.pl
  * remove "^M" (antidos ;))
* Tue Nov  1 2011 lars@linux-schulserver.de
- skip fdupes call and ignore that we might save 4k on the disk
  => fixes bnc #721346
- fix file permissions in docudir
- use nagios-rpm-macros
* Fri Oct  7 2011 lars@linux-schulserver.de
- also check (and fix) the ownership of the directory where
  $status_file lives - Nagios uses this directory for temporary
  files
* Mon Aug  1 2011 schneemann@b1-systems.de
- update to 3.3.1
  FIXES
  * Fixes status.cgi when called with no parameters, where host should be
  set to all if none specified (Michael Friedrich)
  * Fixes possible validation error with empty hostgroups/servicegroups
  (Sven-Göran Bergh)
  * Performance-data handling and checking is now thread-safe so long as
  embedded perl is not used.
  * Children should no longer hang on mutex locks held in parent for
  localtime() (and similar) calls.
  * Debug logging is now properly serialized, using soft-locking with a
  timeout of 150 milliseconds to avoid multiple threads competing for the
  privilege to write debug info.
  * Fixed extraneous alerts for services when host is down
  * Fixed incorrect parsing of multi-line host check results (Jochen Bern)
  * Fixed bug with passive host checks being incorrectly sent to event
  brokers as active checks
  * Fixed bug where passive host check status updates were not being
  propagated to event brokers
* Tue Jul 26 2011 andrea.turrini@gmail.com
- fixed typos in nagios.spec
* Fri Jul  8 2011 lars@linux-schulserver.de
- removed setuid bit from /var/spool/nagios - configure the
  right permissions on service start instead
- use the right STDERR in the cron script
- cleanup files section
* Tue Jul  5 2011 lars@linux-schulserver.de
- integrated cron script from Daniel Kozar (bnc#701208)
* Mon Jul  4 2011 lars@linux-schulserver.de
- fixes in init script if check_external_commands are enabled
- added nagios-3.2.3-CVE-2011-1523.patch to fix
  CVE-2011-1523 (bnc#682966)
* Sun Mar 13 2011 lars@linux-schulserver.de
- install /var/spool/nagios with setgroup bit set, so all new files
  in this directory belong to the command group (maybe we should
  use a permissions file for this?)
* Wed Oct  6 2010 lars@linux-schulserver.de
- update to 3.2.3:
  + Fixes problem where disabling all active hosts/services was not
    taking effect
  + Fixes for compiler warnings (code cleanup by Stephen Gran)
  + Fixes for format errors in event handler logging (Guillaume Rousse)
  + Fixed incorrect info in sample nagios.cfg file for
    state_retention_file (Michael Friedrich)
  + Fixed broker_event_handler() to return ERR if data is NULL
    (Michael Friedrich)
- rebased all patches
- adapted nagios-disable_phone_home.patch
* Mon Sep 20 2010 schneemann@b1-systems.de
- removed unneeded filter "permissions-directory-setuid-bit" from
  nagios-rpmlintrc
* Tue Sep  7 2010 schneemann@b1-systems.de
- cleaned spec and sources, removed unused patches from source
* Wed Sep  1 2010 schneemann@b1-systems.de
- reworked phone-home patch
* Wed Sep  1 2010 schneemann@b1-systems.de
- Update to nagios 3.2.2, excerpt from changelog:
  FIXES
  * Fix for choosing next valid time on day of DST change when clocks go
  one hour backwards
  * Fix for nagios now erroring when "Error: Could not find any
  contactgroup matching..." displayed
  * Fix tap tests for Solaris 10 and newer versions of Test::Harness
  * Fix for notifications not being sent out when scheduled downtime is
  cancelled (Daniel Pouzzner)
  * Fix for first notification delay being calculated incorrectly, and
  notifications potentially going out early (Pawel Malachowski)
  * Fix for text of scheduling downtime of all services on a host (Holger
  Weiss)
  * Fix for services inheriting notification period from hosts if not
  defined (Gordon Messmer)
  * Fix for incorrect service states on host failures (bug #130 Petya Kohts)
  * Fix for incorrect service state attributes being set on host failures
  (bug #128 Petya Kohts)
  * Fix for non-scheduled hosts and services not being updated in NDOUtils
  * Fix for incorrect host state counts in status CGI when viewing
  servicegroups (bug #72)
  * Fix for new Splunk integration query parameters (bug #136)
  * Fix for extra field header in availability CSV export (bug #113)
  * Fix for macro processing code modifying input string (Jochen Bern)
  * Fix for event execution loop re-scheduling host checks instead of
  executing them if service checks are disabled (bug #152)
  * Fix for segfaults on Solaris (Torsten Huebler)
  * Fix for incorrect comment expiration times being passed to event
  broker (Mattieu Kermagot)
* Thu Jul 15 2010 lars@linux-schulserver.de
- back to the old file permissions (once again for clean
  nagios support)
- readded nonsense stuff again
- create/fix check_result_path if needed
* Fri Jul  9 2010 chris@computersalat.de
- fix file/dir perms
  o once again for centreon support
- spec mods
  o sort TAGS
  o added lost Authors (description)
  o macros
  o remove nonsense stuff
* Thu Jun 24 2010 lars@linux-schulserver.de
- rebase phone-home patch
* Tue Jun 22 2010 lars@linux-schulserver.de
- recommend nagios-plugins only to avoid buildcycles
* Fri Jun 18 2010 lars@linux-schulserver.de
- fix init script: touch files if they do not exist-
* Fri May 28 2010 lars@linux-schulserver.de
- disable patch8 - needs rebasing
- install PIDDIR if it's not /var/run to avoid owner problems
  during start
- always change ownership of standard files to the right values
* Mon May 24 2010 lars@linux-schulserver.de
- fix 'Schedule downtime for this host and all services' behavior
  (http://tracker.nagios.org/view.php?id=133)
- fix typos resulting in non used style declarations
  (http://tracker.nagios.org/view.php?id=150)
- fix deleting comments from the hashlist
  (http://tracker.nagios.org/view.php?id=80)
- rebase nagios-p1.pl-location.patch
- fix a handful compiler warnings
- do not allow nagios to phone home: disable online_update_checks
- fix command-group
- BuildRequire net-tools for enabling WAP
* Fri May 14 2010 lars@linux-schulserver.de
- check_verbose now always prints the resulting logfile - this
  allows to see the warnings
* Tue May 11 2010 lars@linux-schulserver.de
- ghost the pid directory
* Wed May  5 2010 lars@linux-schulserver.de
- fix broken files section
- init skript now handles /var/run on tmpfs
- small adaptions of init skript
- default pidfile now /var/run/nagios/nagios.pid
- add manpages from Debian package
- add Debian patches:
  + nagios-fix_forced_servicechecks.patch
  + nagios-fix_encoding_trends.cgi.patch
  + nagios-fix_spurious_dollar_signs_added_to_command_lines.patch
* Tue Apr  6 2010 chris@computersalat.de
- cleanup source
  o removed nagios-3.2.0
* Wed Mar 10 2010 lars@linux-schulserver.de
- update to 3.2.1:
  Enhancements:
  + Link to allow scheduling downtime for all services on a host
  + Speedup to CGIs when lots of comments or downtimes in status.dat file
  + Patch for new_mini_epn to allow for any command line length without
    breaking extra trailing or leading whitespace
  Fixes:
  + Fix for incorrect scheduling when time has gone back an hour
    (partial fix for 24x7)
  + Fix for logging test, which was not timezone aware
    (bug #0000077 - Allan Clark)
  + Fix for CSS validation of padding: X
  + Fix for documentation re: case-insensitive nature of custom
    variables (Marc Powell)
  + Fix for template configurations which use negated wildcards
    (Tim Wilde)
* Mon Nov 23 2009 cschneemann@suse.de
- changed path to send_nsca in the eventhandler script according
    to the path given in the nagios-nsca package. BNC #486937
* Fri Nov  6 2009 chris@computersalat.de
- added lost changes
  o Jun 24 2009
  o Jun 23 2009
- spec mods
  o removed changelog
  o added LEGAL to doc
  o simplify install of extra SOURCES
- added support for centreon
  o centreon is frontend GUI for nagios
  o changed perms/ownership in files section
* Fri Aug 21 2009 chris@computersalat.de
- cleanup spec
  o fixed header
  o sorted TAGS
- fixed deps
  o added missing Req nagios-plugins
* Fri Aug 14 2009 cschneemann@suse.de
- added Requires php and mod_php_any
* Thu Aug 13 2009 cschneemann@suse.de
- added ndo2db to Should-Start/Should-Stop in rcnagios
  changed permission of resource.cfg (needed by centreon)
    (Changes by chris@computersalat.de)
* Wed Aug 12 2009 cschneemann@suse.de
- update to 3.2.0:
  * Fix for read-only permissions bug in CGIs that caused problems viewing
  comments (bug #0000029)
  * Fix for incorrect CGI reports (availability, trends, etc.) when
  reporting period spans Daylight Savings Time (bug #0000046)
  * Fix for detection of truecolor support in GD library (Lars Hecking)
  * Reverted to use --datadir configure script option instead of the more
  recently introduced --datarootdir option
  * Status and retention files are now flushed/synced to disk to prevent
  incomplete information being displayed in CGIs
  * Fix for incorrect next service check time calculation when Nagios is
  reloaded with different timeperiod ranges
  * Updated Fedora quickstart guide to indicate PHP requirements
  * Known issue: Service checks that are defined with timeperiods that
  contain "exclude" directives are incorrectly re-scheduled.  Don't use
  these for now - we'll get this fixed for 3.4
* Wed Jun 24 2009 cschneemann@suse.de
- update to 3.1.2
  - fixes bug in host/service schduling logic that caused excessive
    CPU usage introduced with 3.1.0
* Tue Jun 23 2009 cschneemann@suse.de
- update to 3.1.1
  * New "important check command" flag for use in service templates, to
    aid configuration in distributed environments
  * Fix for nagios validation error when no services defined
  * Fix for stylesheet link
  * Fix for extinfo.cgi error message when cgi.cfg doesn't exist
  * Fix for notifications.cgi where Update button on right didn't retain
    host information when no host= was in query parameters
  * Fix for potential bug where a contactgroup with no members could cause
    parsing errors
  * Fix for W3 validation for history.cgi
  * Fix for W3 validation for extinfo.cgi
  * Fix for nagiostats to return non-zero with failures in MRTG mode
  * Added t/ directory for tests. Use make test to run. Requires perl on
    development server
  * Fix for duplicate event_id attributes in status and retention data
  * Fix for duplicate unlink() during check processing
  * Added missing check period column to host config display (CGI)
  * Fix for embedded Perl initialization under FreeBSD
  * Fix for incorrect re-initialization of mutext after program restart
  * Fix for incorrect weighting in host flap detection logic
  * Added libtap to distribution. Use ./configure --enable-libtap to compile
  * nagios.log permissions are now kept after log rotation
  * Fix for "Max concurrent service checks (X) has been reached" messages
  - will now push services 5 + random(10) seconds ahead for retry
  * Fix for removing old HTML files for web frontend that are now replaced
    with PHP equivalents (in dex/main/side.html)
  * Fix for incorrect service history link text in CGIs
  * Fix for useless code loop in netutils.c
  * Fix for potential divide by zero in event scheduling code
  * Fix for trailing backslash in plugin output causing memory corruption
    in CGIs
  * Fix for bug that could affect host/service scheduling during clock
    time skew or changes to time perod definitions between restarts
  * Leading whitespace from continuation lines in configuration files is
    now stripped out
  * Fix for bug where pipe (used by IPC) file descriptors get inherited by
    child processed (e.g. event handlers) (bug #0000026)
  * Fix for failure to daemonize - Nagios now bails (bug #0000011)
  * Fix for notifications about flapping starting not processed properly
    by retention data
  * Patch to add transparency to statusmap icons for truecolor images
  * Patch to add read-only permissions to extinfo CGI
  * Security fix for statuswml.cgi where arbitrary shell injection was
    possible
* Fri Mar 27 2009 cschneemann@suse.de
- added check_verbose to rcnagios to print the error messages
    directly instead of pointing to the error_log BNC #486912
* Tue Mar  3 2009 cschneemann@suse.de
- changed rcnagios to delete control characters from values
    BNC #480747
* Tue Dec  9 2008 cschneemann@suse.de
- update to 3.0.6:
  + Fix for CGI submission of external commands (writing newlines
    and submitting service comments)
  + Fix for Apache group membership in RPM spec file
  + Fix for improper notification propagation command processing
  + Better out-of-disk-space error handling when writing retention
    and status files
  + Disabled adaptive check and eventhandler commands for security
    reasons
  + Fix for reading output from system commands (event handlers,
    etc) that have timed out
  + Added wildcard host matching in CGIs
  + Fixes for playing audio alerts in CGIs
  + Fix for incorrect host status links in status CGI when viewing
    hostgroup summary
  + Added support for x509 cert authentication in the CGIs
* Mon Dec  1 2008 lrupp@suse.de
- don't fail if the host has problems to execute newaliases
* Mon Nov 10 2008 lrupp@suse.de
- update to 3.0.5:
  + Security fix for Cross Site Request Forgery (CSRF) bug reported
    by Tim Starling.
  + Sample audio files for CGIs removed from distribution
  + Fix for mutliline config file continuation bug
  + Minor sample config file fix
  + Added documentation on CGI security issues
- added permissions-directory-setuid-bit for /var/spool/nagios
* Tue Oct 28 2008 lrupp@suse.de
- use relative pathnames in %%%%post
* Fri Oct 17 2008 lrupp@suse.de
- update to 3.0.4:
  + Fix for properly terminating plugins when parent processes get
    killed (e.g. using 'killall nagios' with check_timeout plugins
    running)
  + Fix for event broker callback when service notifications are
    disabled
  + Fix for scheduling scheduling servicegroup downtime with
    'hosts too' option in CGIs
  + Fixes for bugs in sample event handlers - stop/start active
    service checks and enable notifications
  + Cosmetic fix for logging of notifications
  + Fix for host/service name encoding in CGIs (trends and
    availability reports, etc.)
* Mon Sep 15 2008 lrupp@suse.de
- be a bit more secure in %%post scripts
- fix ownership of resource file in init script
- enhance the README.SuSE a bit
- Recommend cron
* Mon Jul 21 2008 lrupp@suse.de
- fix fillup call
- update to 3.0.3:
  + Minor bug fixes in CGIs
  + Minor bug fix in navigation frame
  + Better error logging during fork() errors
  + Fixed bug in parsing host dependencies
  + Updated p1.pl to allow for 4KB lines in Perl plugin output
  + Fixed bug in command for disabling contact notifications
  + Fix for bugs in host and service orphan check logic
  + Fix for properly escaping macros containing URLs
  + Patches for possible XSS vulnerability in CGIs (CVE-2007-5803)
  + Changes to service check event broker logic (DNX patches)
  + Fixes for url encoding
  + Fix for debug logging of notifications
  + Segfault fix in history CGI
  + Typo fix in object config routines
* Thu May 29 2008 olh@suse.de
- fix missing return value in run_async_service_check (bnc#395203)
* Thu Apr 24 2008 olh@suse.de
- require mailx (bnc#383209)
* Tue Apr 22 2008 olh@suse.de
- fix cron logfile-check in /var/log/nagios/archives/ (bnc#381857)
* Thu Apr  3 2008 lrupp@suse.de
- update to 3.0.1:
  + Fixed bug in trends CGI with user not being authorized
    for hosts/services
  + Fixed bug in status CGI with page layout messing up when
    sounds enabled
* Thu Mar 13 2008 lrupp@suse.de
- update to 3.0 (final):
  + Faster program startup times (especially in large installs)
    with new object lookup code
  + Fix for special contact inheritance rules in
    host and service escalations
  + Fix for bug in processing $CONTACTADDRESSx$ macros
  + Documentation fixes
- Recommend perl
* Wed Mar  5 2008 lrupp@suse.de
- update to 3.0rc3:
  + New macros have been added
  + The old $NOTIFICATIONNUMBER$ macro has been deprecated in favor
    of new $HOSTNOTIFICATIONNUMBER$ and $SERVICENOTIFICATIONNUMBER$
    macros.
  + The $HOSTNOTES$ and $SERVICENOTES$ macros may now contain
    macros themselves
  + new 'enable_environment_macros' option, which allow to disable
    global macros for use in check, event handler, notification,
    and other commands on large installations
  + scheduled downtime entries are now stored in the status file
    and retention file, respectively
  + Current and retained comments are now stored in the status file
    and retention file, respectively
  + Acknowledgement comments that are marked as non-persistent are
    now only deleted when the acknowledgement is removed.
  + Comment and downtime IDs are now retained across program
    restarts and should be unique unless the retention data is
    deleted or ignored.
  + Added flap_detection_options directive to host and service
    definitions to allow you to specify what host/service states
    should be used by the flap detection logic
  + Added a new PROCESS_FILE external command to allow processing
    of external commands found in an eternal (regular) file.
  + Contact status information (last notification times,
    notifications enabled/disabled, etc.) is now saved in the
    status and retention files, although it is not processed
    by the CGIs.
  + check timeperiod for hosts and services can now be modified
    on-the-fly
  + Multiline plugin output is now supported for host and
    service checks
  + Nagios now checks for orphaned service checks by default.
  + Host checks are now run in parallel
  + Timeperiods were overdue for a major overhaul
  + Added event broker callbacks for adaptive programm and contact
    status data
  + ... (See ChangeLog for more details)
- Logfiles are stored in /var/log/nagios now
- Nagios uses own logrotation - but we bzip the old logfiles via
  weekly cronjob (Requires: bzip2)
- added sysconfig file for timeout and nice level
- overhaul the init script
- added a README.SuSE
- added rpmlintrc
- added config.err file as %%ghost
- use upstream macros for all steps during rpmbuild where possible
- adapt to work on all (open)SUSE distributions
- overhaul the patches
- cmdusr is now wwwrun and not nobody
- cmdgrp is now new group nagcmd and not www
- split out devel package
- enable event-broker
- use upstream apache config
- adapt the generated sample configurations so the work out of the
  box
- enable template-objects
- prepare and own the directory for event brokers
- include all sample configuration in docdir
- use fdupes
- create/update new groups/users in %%pre of the (sub-)package
- add the apache2 user to the nagcmd group in %%post of nagios-www
- restart apache2 if nagios-www changes
- own some %%ghost files with the correct permissions
* Fri Oct 26 2007 tsieden@suse.de
- update to nagios version 2.10
  * Added 'make install-webconf' command to install Apache web config file
  * Sample config files are now installed without a -sample extension
  * Fix for SIGTERMs being seen as SIGEXITs, non-logging of SIGTERMs/shutdowns
  * Minor fix for notification timeout log messages
  * Fix for not logging passive host check results
  * Minor bug fixes in CGIs
  * Fix for a segfault when processing passive host check results with empty output/perfdata
  * Fix for incorrect latency calculation for passive service checks
  * Bug fix with attempting to access an uninitalized mutex if external commands are disabled
  * Fix for keeping service checks in the event queue when active service checks are disabled globally
  * Fix for a potential cross site scripting vulnerability in the CGIs
  * Program version is now displayed in CGIs
- removed obsolete FAQ patch in html/docs dir
* Sun Sep 16 2007 cschneemann@suse.de
- added openssl-devel to BuildRequires to support SSL in check_http
* Sun Aug 12 2007 olh@suse.de
- move p1.pl to /usr/lib/nagios/p1.pl
  set 0755 permissions for executable files (157814)
* Wed May 16 2007 lrupp@suse.de
- build on older distributions:
  BuildRequires: libapr0 XFree86-devel XFree86-libs
* Fri May  4 2007 tsieden@suse.de
- update to nagios version 2.9
  * Fix for incorrect performance data file write/append mode options
  * Fix for current status of hosts with no host check command defined
  * SIGSEGV signals should now be logged again (broken in 2.8)
  * Configure script fix for no mail program found/installed on system
  * Configure script option bug fixes for cygwin and embedded perl
  * Command definitions and host/service plugin perfdata with HTML should now be escaped in CGIs
  * Patch for incorrect time down percentage in availability CGI
  * Updated init script to fix a race condition during restarts
* Mon Mar 12 2007 tsieden@suse.de
- update to nagios version 2.8
  * Bug fix for calculating notification interval with service escalations
  * Bug fix for using servicegroups in service dependency definitions
  * Bug fix for bad date format submission in command CGI
  * Possible segfault fix during restarts when daemon was performing host checks
  * Fix for missing check timeout in event broker calls
  * Fix for handling signals under NPTL
  * Added error messages for passive service checks that don't correspond to a defined service
* Fri Feb  9 2007 tsieden@suse.de
- update to nagios version 2.7
  * p1.pl now sets environment var (NAGIOS_PLUGIN) to indicate patch of plugin that is executing
  * Updated nagiostats with new MRTG vars for tracking buffer usage
  * Added sample MRTG config file
  * Minor patches to availability and status CGIs
  * Minor documentation updates
  * Fix for segfault during expiration or deletion of scheduled downtime
  * Fix for scheduling immediate service check through WAP interface
  * Fix for leading whitespace before comments in object config files
* Thu Feb  1 2007 olh@suse.de
- add quick-start.txt (#237372)
* Thu Feb  1 2007 olh@suse.de
- remove unneeded trailing slashes from Alias and Directory entries
  in nagios-http.conf
* Wed Jan 17 2007 olh@suse.de
- fix more comparison with string literal in avail.c
* Thu Jan 11 2007 olh@suse.de
- FATE #301512
* Thu Jan 11 2007 olh@suse.de
- fix typo in html docu, perdata.html -> perfdata.html
* Thu Jan 11 2007 olh@suse.de
- correct link to external FAQ website
* Thu Jan 11 2007 olh@suse.de
- correct Alias in nagios-httpd.conf
* Wed Jan 10 2007 olh@suse.de
- update the default example config to mail to nagios%%localhost
  instead to non-existant nagios-admin%%localhost
* Wed Jan 10 2007 olh@suse.de
- fix comparison with string literal (#232415)
* Mon Jan  8 2007 olh@suse.de
- move pid file to /var/run/nagios/ (#231169)
* Fri Dec  1 2006 tsieden@suse.de
- update to version 2.6
  * fix for unscheduled triggered downtime entries
  * fix for embedded audio in tac and status CGIs
  * fixed bug in nagiostats utility when reporting host/service check latency
  * misc code cleanups for compiler warnings
  * fixed error when reading empty (zero byte) config files
  * default is now to check for orphaned service checks (Francois Caen)
  * fixed bug with non-standard CGI config file location in status data (Carson Gaspar)
  * fixed bugs and simplified examples in sample config files (Mark Young)
  * removed obsolete patches which are included in upstream now
- fixed "empty PID file error" in init script
* Thu Nov 16 2006 tsieden@suse.de
- changed home dir to /var/lib/nagios (#221791)
* Tue Oct 17 2006 olh@suse.de
- fix uninitialized variable in run_global_service_event_handler (212892)
* Mon Sep 18 2006 olh@suse.de
- add a user/group nagios (#61908)
* Fri Sep  8 2006 olh@suse.de
- update to version 2.5
  disable sapmon patch for the time being
* Wed May 24 2006 schwab@suse.de
- Don't build as root.
- Don't strip binaries.
- Fix format string bug.
* Wed May  3 2006 stark@suse.de
- fixed possible buffer overflow in CGI scripts (#140494)
  (CVE-2006-2162)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 stark@suse.de
- fixed off-by-one overflow (#141124)
* Fri Nov 18 2005 stark@suse.de
- update to stable version 1.3
* Thu Oct  6 2005 stark@suse.de
- fixed autobuild warnings about printf format
* Sat May 14 2005 stark@suse.de
- fixed compiler errors about usage of uninitialized vars
* Sun Apr 24 2005 aj@suse.de
- Compile with GCC4.
* Mon Aug 30 2004 ro@suse.de
- removed apache1 traces
* Mon May  3 2004 stark@suse.de
- fix compiler-warnings
* Tue Feb  3 2004 stark@suse.de
- update to nagios 1.2
* Thu Sep 18 2003 stark@suse.de
- /usr/lib/nagios and /usr/lib/nagios/plugins are owned
  by root (#31100)
* Mon Sep  8 2003 stark@suse.de
- add apache2 config-files, require http_daemon
  and need apache2-devel-packages for build (#30157)
* Wed Aug 27 2003 ro@suse.de
- remove traceroute-lbl from neededforbuild
  traceroute from net-tools is used anyway
* Mon Aug 18 2003 stark@suse.de
- added activation meta-data to sysconfig (#28830)
* Fri Aug 15 2003 poeml@suse.de
- change cmdgrp from nogroup to www (the group apache now runs
  under) [#21782]
- implement try-restart correctly
* Thu Jul 31 2003 stark@suse.de
- use stop/restart macros
* Tue Jul 29 2003 aj@suse.de
- Fix chown invocation.
* Fri Jul 25 2003 stark@suse.de
- added bugfixes
* Thu Jun 12 2003 kukuk@suse.de
- Make sure plugin directory exist
* Thu Jun 12 2003 kukuk@suse.de
- Add nagios libdir to filelist
* Wed Jun  4 2003 stark@suse.de
- update to bugfix release 1.1
  * File descriptor leak in file-based performance routines
  * Timestamp fix for PostgreSQL 7.3
  * Minor bug fixes to cmd and history CGIs
  * Minor documentation fixes
* Mon Jan 13 2003 stark@suse.de
- added sysconfig-metadata (#22607)
* Mon Dec  2 2002 stark@suse.de
- adopted sapmoni.dif for gcc 3.3
* Mon Nov 25 2002 stark@suse.de
- update to 1.0 final
  * Minor bug fixes in CGIs
  * Minor doc updates
  * Bug fix for flex host downtime
  * Embedded perl bug fixe for arguments with spaces
  * Host escalation logic fix
* Tue Oct 15 2002 stark@suse.de
- running pre-flight configuration check always when
  starting nagios (#20916)
- added logrotate definitions for logfiles
- fixed embedded perl (#20916) (thanks to mls)
* Mon Sep 23 2002 stark@suse.de
- update to 1.0b6
  * Added wildcards and multiple hosts/hostgroups to host dependency
    and service dependency definitions
  * Added wildcard support for members directive in hostgroup
    definitions
  * Minor bug fixes and cleanups in CGIs
  * Minor cleanups in the core
  * New version of snprintf() included that supports %%f
  * Notification interval for escalations now defaults to
    non-escalated value
* Fri Aug 23 2002 stark@suse.de
- update to 1.0b5
  * Fixed memory leak related to processing of passive checks
  * Memory leak fixes in the CGIs
  * Minor interface changes to the status and TAC CGIs
  * Bug fix in the notification CGI
  * Added minimalistic sample object config file (minimal.cfg)
* Fri Aug 16 2002 stark@suse.de
- added PreReq (Bug #17938 #17939)
* Mon Aug 12 2002 stark@suse.de
- updated sapmoni patch to provide documentation
* Mon Aug 12 2002 mls@suse.de
- made it work with threaded perl-5.8
* Thu Aug  8 2002 stark@suse.de
- added patch to be able to use nagios-plugins-sap
* Sat Jul 27 2002 adrian@suse.de
- fix neededforbuild
* Fri Jul  5 2002 stark@suse.de
- update to 1.0b4
  * Address field in host definitions is now optional in
    template-based config format. Defaults to host name if not
    specified.
  * Fixed memory leak when processing passive checks
  * Added illegal_macro_output_chars variable to main config file
    to allow for stripping dangerous shell characters from plugin
    output
* Wed Jun 12 2002 stark@suse.de
- removed -devel subpackage and moved the file to main-package
* Mon Jun 10 2002 stark@suse.de
- update to 1.0b3
  * Bug fixes in template-based object code
  * Bug fix in tac CGI for counting host and service states
    properly
  * Default is now to check for external commands as often as
    possible
  * Ping syntax for WAP interface moved to CGI config file
  * Command file user/group defaults to Nagios user/group unless
    overridden with configure script options
  * Sample template-based object config file fixes
* Tue May 28 2002 stark@suse.de
- update to 1.0b2
  * Fixed bug with escaping strings for DB support
    (MySQL & PostgreSQL)
  * Several bug fixes in template-based object code
  * Multiple hostgroups supported in host and service escalations
  * Wildcard support in service, service escalation, and host
    escalation definitions
* Thu May 23 2002 stark@suse.de
- install config-file templates
* Wed May 22 2002 stark@suse.de
- initial version of Nagios (the successor of NetSaint)
